PRO CALC_FINV, style, nlev_1, lev_1, numlev, htp, hbt, Pobs, Finv, $
               fine=finex
;+ 
; NAME: calc_finv
; PURPOSE: calculate the inverse of the trapezoid matrix 
; 
; INPUT: 
;
;  Name          Description 
; ------    ----------------------
; style     1 for Moore-Penrose pseudoinverse
;           2 for slab averages
; nlev_1    number of coarse levels (topography corrected)
; lev_1     coarse level boundaries 
; numlev    number of levels (RTA grid)  
; htp       halftop
; hbt       halfbot
; Pobs      Pressure of RTA grid

; OUTPUT  

; Finv      Inverse matrix of the trapezoids
; 
;- 
  ndim = nlev_1-1
  CASE style OF 
    1L: BEGIN
      ; calculate trapezoids the trapezoids
      finea = FLTARR(ndim, numlev)
      FOR il = 0L, ndim-1 DO BEGIN
          slbval = FLTARR(ndim)
          slbval(il) = 1.0
          fine = FLTARR(numlev)
          SLB2FIN, nlev_1, lev_1, slbval, htp, hbt, $
                   1100., Pobs, fine 
          finea(il,*) = fine    ;/TOTAL(fine)
      ENDFOR  

      finex = finea

;      fine2 = FLTARR(ndim,ndim)
;      finext = TRANSPOSE(finex)
;      FOR j = 0, ndim-1 DO BEGIN
;        FOR i = 0, j DO BEGIN
;          dsum = 0.0d0
;	  FOR k = 0, numlev-1 DO BEGIN
;            dsum = dsum + (DOUBLE(finext(k,i))*DOUBLE(finext(k,j)))
;          ENDFOR
;	  fine2(i,j) = FLOAT(dsum)
;	  fine2(j,i) = FLOAT(dsum)
;       ENDFOR
;      ENDFOR
      
      ; calculate the interpolation matrix 
      fftr   = MATRIX_MULTIPLY(DOUBLE(finea),DOUBLE(finea),/BTRANS)
      status = 1L

     finv1  = LA_INVERT(fftr,STATUS=status,/DOUBLE)
    
     ; =============================================================== 
     ; this is the inverse of the interpolation functions (trapezoids)
     ; retrieval basis
     finv = MATRIX_MULTIPLY(finv1,DOUBLE(finea))
  
   END
   2L: BEGIN
     ; calculate trapezoids the trapezoids
     finea = FLTARR(ndim, numlev)
     FOR il = 0L, ndim-1 DO BEGIN
        slbval = FLTARR(ndim)
        slbval(il) = 1.0
        fine = FLTARR(numlev)
        SLB2FIN, nlev_1, lev_1, slbval, htp, hbt, $
                 1100., Pobs, fine 
        finea(il,*) = fine
     ENDFOR  
     finex = finea
     finv = DBLARR(ndim,numlev)
     FOR il = 0L, ndim-1L DO BEGIN
       N = lev_1(il+1) - lev_1(il) + 1
       iavg = lev_1(il) + LINDGEN(N) - 1L ; offset for IDL indx
       finv(il,iavg) = 1.0d0/DOUBLE(N)  ; all elements are normalized
       
     ENDFOR
     FOR il = 0L, ndim-1 DO $
        finea(il,*) = finea[il,*]/TOTAL(finea[il,*])
              
     finv = finea  ; just take the transpose
     
;     finv = SMOOTH(finv,2)
;     stop
   END
   ELSE: STOP
 ENDCASE  
END 
