pro nsplot_2panel_ak_retdiff,xtype,sattype,orbit,ifor,igran,datestr
; Nadia Smith
; nadias@stcnet.com
; 
; ===========================================
; plot granules
; ===========================================
;datestr='20180701'
yy=strmid(datestr,0,4)
mm=strmid(datestr,4,2)
dd=strmid(datestr,6,2)

; set up directories
basedir='/peate_sci/cbarnet/satellite/'
if strcmp(sattype,'snpp.fsr') eq 1 then ddir=basedir+'npp/'+yy+'/'+mm+'/'+dd+'_fsr/'
if strcmp(sattype,'snpp.nsr') eq 1 then ddir=basedir+'npp/'+yy+'/'+mm+'/'+dd+'_nsr/'
if strcmp(sattype,'n20') eq 1 then ddir=basedir+'n20/'+yy+'/'+mm+'/'+dd+'/'
if strcmp(sattype,'aqua') eq 1 then begin
	ddir=basedir+'aqua/'+yy+'/'+mm+'/'+dd+'/'
	if strcmp(xtype,'clim') eq 1 then xdir='claq'
endif else begin
	if strcmp(xtype,'clim') eq 1 then xdir='climcaps'
endelse
if strcmp(xtype,'nu') eq 1 then xdir='nucaps'
figtit=strupcase(sattype)

; define constants
fillval=9.96921e+36
nan=!Values.F_NAN
; --- Load standard retrival pressure levels (pobs)
get_p100, pstd, pobs,peff=stdpeff
nlev=n_elements(pobs)

imaxlist=[0.5,0.5,0.5]
;paramlist=['air_temp','h2o_vap','o3']
paramlist=['h2o_vap']
collist=['deep pink','fuchsia','medium orchid','violet','plum','rosy brown','tan','sandy brown',$
	'peru','chocolate','sienna','dark salmon','coral','tomato','orange red','dark orange',$
	'orange','goldenrod','dark goldenrod','gold','olive','olive drab','dark green','forest green',$
	'sea green','medium sea green','spring green','light green','aqua','light sea green']
print,n_elements(collist)

; ===============================
; find and open files *.f93, *.ret, *.fg
filespec=ddir+xdir+'_'+orbit+'/*.ret'
filelist=findfile(filespec)

; select one granule based on user input, igran
fnret=filelist(igran-1)
pos=strpos(fnret,'.ret')
fnak=strmid(fnret,0,pos)+'.f93'
fnfg=strmid(fnret,0,pos)+'.fg'
print,'reading file ',fnak
nobs=1345

; =============================================
; =============================================

;         Loop over parameter list

; =============================================
; =============================================
; now read granules
; --- Open .f93 file; averaging kernels
close, 1
open_f93, fnak, f93, /binary, unit =1
; --- Open .ret file; retrievals
close, 4
openl2_b, fnret, iret, retgran, unit = 4
; --- Open .fg file; first guess values
close, 2
openl2_b, fnfg, ifg, fggran, unit=2
; --- Read number of records

; ===================================
ret=fltarr(nlev)*nan
fg=fltarr(nlev)*nan
ak=fltarr(nlev)*nan
cfrac=fltarr(nobs)*nan
trapeff=fltarr(nobs)*nan
;idxarr=[110,171,546,670,808,1018,1162,1223]
for iobs=0,nobs-1,10 do begin
;foreach iobs,idxarr do begin
	read_f93,f93,unit=1; AK record
	readl2_b,iret,retgran,unit=4; Retrieval record
	readl2_b,ifg,fggran,unit=2; First Guess record
;	if (iobs gt ifor) and (iobs lt ifor+60) then begin
;	if retgran.ispare(1) eq 0 then begin
	for ip=0,n_elements(paramlist)-1 do begin
		case 1 of
			strcmp(paramlist(ip),'air_temp'): param='temp'
			strcmp(paramlist(ip),'h2o_vap'): param='wcd'
			strcmp(paramlist(ip),'o3'): param='ocd'
		endcase
		str='ret=retgran.'+param
		dum=execute(str)
		str='fg=fggran.'+param
		dum=execute(str)
		cfrac=retgran.cldfrc(0)
		ctp=retgran.pcld(0)
		cceta=retgran.rspare(28)
		ccampl=retgran.rspare(5,*)
		plat=string(round(retgran.alat*100)/100.,format='(f7.2)')
		plon=string(round(retgran.alon*100)/100.,format='(f7.2)')
		qc=retgran.ispare(1)
		if qc gt 0 then qc=1 else qc=0
		print,'qc=',qc
		psurf=retgran.psurf

		; find bottom layer at surface
		botlev=100
		lsurface,botlev,pobs,psurf,50.,1100.
		if (botlev lt nlev-1) then fg(botlev:nlev-1)=nan
		if (botlev lt nlev-1) then ret(botlev:nlev-1)=nan
	; AK parameters
		case 1 of
			strcmp(paramlist(ip),'air_temp'): begin
                		dbmax=double(f93.tmpwgt); ozone, .tmpwgt, .watwgt
                		aknlev=f93.nlevtmp; nlevtmp, nlevwat
	        	        trap_idx=f93.levtmp(0:aknlev-1); levtmp,levwat
		                htop=f93.tmptop; tmptop, wattop
                		hbot=f93.tmpbot; tmpbot, watbot
	                	phi_lim = f93.phi_limit
	        	       	ndim=f93.ndimtmp; ndimtmp, ndimwat
        		        lambda_vec=reform(f93.tmplam(1,*,*)); watlam; tmplam
	        	        eigvec_mat=reform(f93.tmpeig(1,*,*)); wateig,tmpeig
				div=fltarr(nlev)+1.0
				xrange=[-1.5,1.5]
				akrange=[0,0.3]
				paramstr='T!Iair!N'
				aktit=paramstr+' Ave Kern diag'
				xtit=paramstr+' (FG-Ret) [K]'
			end
			strcmp(paramlist(ip),'h2o_vap'): begin
                		dbmax=double(f93.watwgt); ozone, .tmpwgt, .watwgt
		                aknlev=f93.nlevwat; nlevtmp, nlevwat
	                	trap_idx=f93.levwat(0:aknlev-1); levtmp,levwat
        		        htop=f93.wattop; tmptop, wattop
        	        	hbot=f93.watbot; tmpbot, watbot
		                phi_lim = f93.phi_limit
        	        	ndim=f93.ndimwat; ndimtmp, ndimwat
                		lambda_vec=f93.watlam; watlam; tmplam
		                eigvec_mat=f93.wateig; wateig,tmpeig
				div=(fg)
				xtit='H!I2!NO (FG-Ret)/FG [%]'
				xrange=[-0.6,0.6]
				akrange=[-0.06,0.3]
				paramstr='H!I2!NO'
				aktit=paramstr+' Ave Kern diag'
			end
			strcmp(paramlist(ip),'o3'): begin
                		dbmax=double(f93.owgt); ozone, .tmpwgt, .watwgt
	                	aknlev=f93.nlevozon; nlevtmp, nlevwat
	        	        trap_idx=f93.levozon(0:aknlev-1); levtmp,levwat
        	        	htop=f93.otop; tmptop, wattop
	        	        hbot=f93.obot; tmpbot, watbot
        	        	phi_lim = f93.phi_limit
	                	ndim=f93.ndimozon; ndimtmp, ndimwat
   		        	lambda_vec=f93.olam; watlam; tmplam
        		        eigvec_mat=f93.oeig; wateig,tmpeig
				div=(fg)
				xrange=[-0.5,0.5]
				akrange=[0,0.6]
				paramstr='O!I3!N'
				aktit=paramstr+' Ave Kern diag'
				xtit=paramstr+' (FG-Ret)/FG [%]'
			end
		endcase
		diff=fltarr(nlev)
		for ilev=0,nlev-1 do diff(ilev)=(fg(ilev)-ret(ilev))/div(ilev)
		figtit=strupcase(paramlist(ip))
; =====================================
; Reconstruct AK
		lambda_c=1.0d/(dbmax*dbmax)
		ak_rec,ndim,lambda_c,phi_lim,lambda_vec,eigvec_mat,dof,akmat

; extract ak diagonal
		ak = diag_matrix(akmat)

		trap=intarr(aknlev,2)

; Calculate effective pressure of trapezoids
		for i=0,aknlev-2 do begin
        		fine=fltarr(n_elements(pobs))
		        slabval=fltarr(nlev)
        		slabval(i)=1.0
		        slb2fin,aknlev,trap_idx,slabval,htop,hbot,psurf,pobs,fine
        		idx=where(fine eq 0.5)
	        	trap(i,0)=idx(0); top of face
	        	trap(i,1)=idx(n_elements(idx)-1); bottom of face
		        if n_elements(idx) ge 2 then begin
; calculate effective pressure of trap face
		               trapeff(i)=(pobs(trap(i,1))-pobs(trap(i,0)))/alog(pobs(trap(i,1))/pobs(trap(i,0)))
		        endif else begin
               			trapeff(i)=pobs(trap(i,0))
		        endelse
		endfor; loop over trap nlev
; ===================================


; =====================================
; start plotting
; =====================================
; what you want here is two panels with extra stats
		cfracstr='Cfrac='+strtrim(round(cfrac*100),1)+'%'
		ctpstr='CTP='+strtrim(round(ctp),1)+'hPa'
		if qc eq 0 then qcstr='qc=pass'
		if qc eq 1 then qcstr='qc=fail'
		ccetastr='CC-eta='+string(round(cceta*100.)/100.,format='(f4.2)')
		ccamplstr='CC-ampl='+string(round(ccampl*100.)/100.,format='(f4.2)')
		if qc eq 1 then qcstr='qc=FAIL' else qcstr='qc=PASS'
		if qc eq 1 then qccol='red' else qccol='green'

; Now you can plot the mean and stdev profiles
; setup plot
		yrange=[1000.,10.]
		xticks=[0.,0.1,0.2,0.3]
		yticks=[1000,500,300,100,50,10]
		ytickname=['1000.','500.','300.','100.','50.','10.']
		figtit='CLIMCAPS-'+strupcase(sattype)+' '+datestr+' '+strupcase(orbit)
; PLOT AVERAGING KERNEL
		a=plot(ak,trapeff,ytitle='Pressure [hPa]',$
		/ylog,yrange=yrange,xtitle=aktit,font_size=4,$
		/buffer,/nodata,Title=figtit,margin=[0.18,0.1,0.1,0.1],$; left bottom right top
		color='black',thick=1,dimensions=[240,200],layout=[2,1,1])
		a.xrange=akrange
		a.xgridstyle=1
		a.xthick=0.2
		a.ythick=0.2
		a.xminor=0
		a.yminor=0
		a.ygridstyle=1
		a.ysubgridstyle=1
		a.yticklen=1
		a.xticklen=1
		a.ytickvalues=yticks
		a.xtickvalues=xticks
		 a=plot(fltarr(n_elements(trapeff))+0.1,trapeff,/overplot,linestyle=0,color='linen',thick=4)
		a=plot(ak,trapeff,/overplot,linestyle=0,color='royal blue',thick=1.5)	
;		t1=text(0.2,15,cfracstr,/data,font_size=4,font_color='black',fill_background=1,fill_color='white')
;		t2=text(0.2,20,ctpstr,/data,font_size=4,font_color='black',fill_background=1,fill_color='white')
;		t3=text(0.2,25,ccetastr,/data,font_size=4,font_color='black',fill_background=1,fill_color='white')
;		t4=text(0.2,32,ccamplstr,/data,font_size=4,font_color='black',fill_background=1,fill_color='white')
		t5=text(0.2,40,qcstr,/data,font_style='bold',font_size=4,font_color=qccol,fill_background=1,fill_color='white')
        
; ---- second figure
; what you want here is two panels with extra stats
		cfracstr='Cfrac='+strtrim(round(cfrac*100),1)+'%'
		ctpstr='CTP='+strtrim(round(ctp),1)+'hPa'
		if qc eq 0 then qcstr='qc=pass'
		if qc eq 1 then qcstr='qc=fail'
		ccetastr='CC unc='+string(round(cceta*100.)/100.,format='(f4.2)')
		ccamplstr='CC err='+string(round(ccampl*100.)/100.,format='(f4.2)')

; Now you can plot the mean and stdev profiles
; setup plot
; plot zero line
		geostr='['+plat+','+plon+']'
		a=plot(intarr(nlev)*0,pobs,ytitle='Pressure [hPa]',$
		/ylog,yrange=yrange,xtitle=xtit,font_size=4,$
		/current,/buffer,Title='lat/lon='+geostr,$
		color='dark gray',linestyle=1,margin=[0.18,0.1,0.1,0.1],thick=2,layout=[2,1,2])
		a.xrange=xrange
		a.xthick=0.2
		a.ythick=0.2
		a.xgridstyle=':'
		a.xminor=0
		a.yminor=0
		a.ygridstyle=1
		a.ysubgridstyle=1
		a.yticklen=1
		a.xticklen=1
		a.ytickvalues=yticks
; plot difference
		a=plot(fltarr(nlev)-0.2,pobs,/overplot,linestyle=0,color='linen',thick=4)
		a=plot(fltarr(nlev)+0.2,pobs,/overplot,linestyle=0,color='linen',thick=4)
		;a=plot(diff,pobs,/overplot,linestyle=0,color='violet',thick=1)
		a=plot(diff,pobs,/overplot,linestyle=0,color='black',thick=1.5)

		jname=xtype+'caps_'+sattype+'_'+datestr+'_'+orbit+'_'+paramlist(ip)+'_AK_G'+strtrim(igran,1)+'_FOR'+strtrim(iobs,1)+'.png'
		a.save,jname,resolutiion=120
		print,'figure saved to '+jname
		print,cfracstr+', '+ctpstr+', '+ccetastr+', '+ccamplstr+', '+qcstr
		endfor; condition of success
	;endif; loop over paramlist
endfor;
;endforeach ; loop over obs

end
