pro nsplot_ak_diag2,instr,xtype,orbit,zone,param
tlev=[1,8,10,13,15,19,24,27,32,36,39,43,47,51,56,61,66,71,75,80,$
	83,87,92,100]; levtemp in temp*.nl
o3lev=[1,26,35,39,44,49,56,63,80,100]; levozon in ozone*.nl
watlev=[1, 39, 52, 61, 64, 66, 70, 76, 81, 85, 91, 100]; levwatr in water*.nl


; random file from which to read pressure array
fn='/iliad/proxy/nadias/nucaps/npp/2018/11/15/netcdf/NUCAPS-EDR_v2r0_j01_s201811150659359_e201811150700057_c201811150720280.nc'
out=read_ncdf(fn,dat)
plev=dat.pressure(*,1)

tplev=plev(tlev)
o3plev=plev(o3lev)
watplev=plev(watlev)

case param of
	'q': begin
	akplev=watplev
	yrange=[1000.,100.]
	xrange=[0.,0.45]
	yticks=[1000,800,500,300,100]
	xtitle='H2O Avg Kernel'
	ypos=120
	end
	't': begin
	akplev=tplev
	xrange=[0.,0.45]
	yrange=[1000.,10.]
	yticks=[1000,500,300,100,50,10]
	xtitle='T Avg Kernel'
	ypos=20
	end
	'o3': begin
	akplev=o3plev
	xrange=[0.,0.4]
	yrange=[1000.,0.1]
	end
endcase
aknlev=n_elements(akplev)

; date
daystr='20180321'
datestr='20180321'
yy='2018';strmid:(daystr,0,4)
mm='03';strmid(daystr,4,2)
dd='21';strmid(daystr,6,2)

case zone of 
	0: begin
	zonestr='South Pole [-90,-60]'
	zmin=-90
	zmax=-60
	cmax=0.4
	end
	1: begin
	zonestr='South Mid-Lat [-60,-30]'
	zmin=-60
	zmax=-30
	cmax=0.65
	end
	2: begin
	zonestr='Tropics [-30,30]'
	zmin=-30
	zmax=30
	cmax=0.65
	end
	3: begin
	zonestr='North Mid-Lat [30,60]'
	zmin=30
	zmax=60
	cmax=0.65
	end
	4: begin
	zonestr='North Pole [60,90]'
	zmin=60
	zmax=90
	cmax=0.4
	end
endcase

; data directory
ddir='/iliad/proxy/nadias/'+xtype+'caps/'+instr+'/'+yy+'/'+mm+'/'+dd+'/netcdf'

; output figure name
jname=xtype+'caps_'+instr+'_'+param+'_AK_diag_'+datestr+'_'+orbit+'_zone'+strtrim(zone,1)+'.jpg'

; find all the files to plot
filespec=ddir+'/'+xtype+'caps_'+instr+'_'+orbit+'_zone*'+datestr+'*_AK.nc'
print,filespec
filelist=findfile(filespec)
nfiles=n_elements(filelist)
print,strtrim(nfiles,1)+' files to process'

; start plotting
claser,psfile="unc.eps",/eps
loadct,20
mcolor=byte(!p.color)
if mcolor eq 0 then mcolor=255
icmm1=mcolor-1
icmm2=mcolor-2
!p.background=255.
!p.color=0
!p.thick=2.0
!p.charsize=1.5
loadct,20;33
cnt=0L

;for n=0,100 do begin
for n=0,nfiles-1 do begin
    	print, 'reading file', filelist(n)
	result=read_ncdf(filelist(n),dat)
;------------------------------------------
;	s=size(dat.latitude)
	nprof=n_elements(dat.latitude)
;	nscan=s(2)
	if strcmp(param,'t') then akmatrix=dat.tak2; final T retrieval [24,24,nobs]
	if strcmp(param,'q') then akmatrix=dat.h2oak; averaging kernel [12,12,nobs]
	if strcmp(param,'o3') then akmatrix=dat.o3ak; averaging kernel [10,10,nobs]
        qf=dat.qcmask; [nobs]
	lats=dat.latitude; [nobs]
	lons=dat.longitude; [nobs]

; define output array
	
	if n eq 0 then begin
		akout=fltarr(aknlev,nprof*nfiles)*!Values.F_NAN
		dofout=fltarr(nprof*nfiles)*!Values.F_NAN
	endif
	;if n eq 0 then akout=fltarr(aknlev,nprof*nscan*nfiles)*!Values.F_NAN

; reshape arrays to simplify looping and subsetting
	;qf=reform(qf,nprof*nscan)	
        ;lats=reform(lats,nprof*nscan)
        ;lons=reform(lons,nprof*nscan)
	;print,aknlev
;	akmatrix=reform(akmatrix,aknlev,aknlev,nprof*nscan)

; make geographic subset
	gidx=where(lats lt zmax and lats gt zmin)
	lats=lats(gidx)
	lons=lons(gidx)
	akmatrix=akmatrix(*,*,gidx)
	qf=qf(gidx)
	nelem=n_elements(gidx)

; construct and apply a qc mask
	qualmask=fltarr(nelem)
	qualmask(where(qf eq 0))=1.0
	qualmask(where(qf gt 0))=!Values.F_NAN

; subset ak for specific pressure level
	for i=0,nelem-1 do begin
	        ;ak=reform(diag_matrix(akmatrix(*,*,i,j)))
		;akout(*,cnt)=akmatrix(pidx,*,i)*qualmask(i)
		akout(*,cnt)=diag_matrix(akmatrix(*,*,i))*qualmask(i)
		cnt=cnt+1
	endfor
	
endfor
help,akout
print,'count=',cnt
dofout=fltarr(nprof*nfiles)

akout(where(akout lt -100))=!Values.F_NAN
for i=0,cnt-1 do dofout(i)=total(akout(*,i),/nan)
idx=where(dofout gt 0)

avgdof=round(mean(dofout(idx),/nan)*1000.)/1000.
avgdof=strtrim(avgdof,1)
avgdof=strmid(avgdof,0,4)

;figtit=strupcase(xtype)+'CAPS-S'+strupcase(instr)+' '+strupcase(param)+' AK; DFS='+avgdof+'; '+zonestr
figtit=zonestr
akmean=fltarr(aknlev)
xerr=fltarr(aknlev)
zeroline=fltarr(aknlev)
; calculate mean and stddev of AK profile
for i=0,aknlev-1 do begin
	idx=where(abs(akout(i,*)) gt 0) 
	akmean(i)=mean(akout(i,idx))	
	xerr(i)=stddev(akout(i,idx))
endfor

; plot
a=errorplot(akmean,akplev,xerr,[0],'-b3',Ytitle='Pressure [hPa]',$
	/ylog,yrange=yrange,font_size=14,$
	/buffer,Xtitle=xtitle,Title=figtit,$
	dimensions=[550,800],errorbar_linestyle=1,$
	errorbar_color='tomato',errorbar_thick=3)
	;ytickname=['10','70','100','300','500'],$
	;yminor=-1)
a.xrange=xrange
a.xgridstyle=1
a.xminor=0
a.yminor=0
a.ygridstyle=1
a.ysubgridstyle=1
a.yticklen=1
a.xticklen=1
a.ytickvalues=yticks
t=text(0.3,ypos,'DFS='+avgdof,/data,font_size=14,font_style=1)
;a=plot(akmean-akstd,o3plev,'b*',/buffer,/current,/overplot)
a=plot(zeroline,akplev,/buffer,/current,/overplot,$
	linestyle=1,color='gray')

a.save,jname,resolution=120
print,'figure saved to '+jname
print,'avg dof =', avgdof
end
