pro nsplot_ak_diag_doubleT,orbit,zone,xtype
instr='npp'

tlev=[1,  8, 10, 13, 15, 19, 24, 27, 32, 36,$
      39, 43, 47, 51, 56, 61, 66, 71, 75, 80,83, 87, 92, 100]
; can't plot T AK now because the number of levels vary between 21 and 23. 
; they vary because of topography. Just shave off the bottom layers
;akfn='/iliad/proxy/nadias/nucaps/npp/2018/03/21/netcdf/nucaps_npp_am_zone1_s201803210118070_e201803210126050_AK.nc'

fn='/iliad/proxy/nadias/nucaps/npp/2018/11/15/netcdf/NUCAPS-EDR_v2r0_j01_s201811150659359_e201811150700057_c201811150720280.nc'
out=read_ncdf(fn,dat)
plev=dat.pressure(*,1)
akplev=plev(tlev)
aknlev=n_elements(tlev)

; date
daystr='20180321'
datestr='20180321'
yy='2018';strmid(daystr,0,4)
mm='03';strmid(daystr,4,2)
dd='21';strmid(daystr,6,2)

param='T'
case zone of 
	0: begin
	zonestr='South Pole [-90,-60]'
	zmin=-90
	zmax=-60
	cmax=0.4
	end
	1: begin
	zonestr='South Mid-Lat [-60,-30]'
	zmin=-60
	zmax=-30
	cmax=0.4
	end
	2: begin
	zonestr='Tropics [-30,30]'
	zmin=-30
	zmax=30
	cmax=0.4
	end
	3: begin
	zonestr='North Mid-Lat [30,60]'
	zmin=30
	zmax=60
	cmax=0.4
	end
	4: begin
	zonestr='North Pole [60,90]'
	zmin=60
	zmax=90
	cmax=0.4
	end
endcase

xrange=[0.,0.3]
yrange=[1000.,10.]
yticks=[1000,500,300,100,50,10]
xtitle='T Avg Kernel'

; data directory
ddir='/iliad/proxy/nadias/'+xtype+'caps/'+instr+'/'+yy+'/'+mm+'/'+dd+'/netcdf'

; output figure name
jname=xtype+'caps_'+instr+'_T_AK2_diag_'+datestr+'_'+orbit+'_zone'+strtrim(zone,1)+'.jpg'

; find all the files to plot
filespec=ddir+'/'+xtype+'caps_'+instr+'_'+orbit+'_*'+datestr+'*_AK.nc'
print,filespec
filelist=findfile(filespec)
nfiles=n_elements(filelist)
print,strtrim(nfiles,1)+' files to process'

; start plotting
claser,psfile="unc.eps",/eps
loadct,20
mcolor=byte(!p.color)
if mcolor eq 0 then mcolor=255
icmm1=mcolor-1
icmm2=mcolor-2
!p.background=255.
!p.color=0
!p.thick=2.0
!p.charsize=1.5
loadct,20;33
cnt=0L
; READ NUCAPS FILES
;for n=0,100 do begin
for n=0,nfiles-1 do begin
    	print, 'reading file', filelist(n)
	;result=read_ncdf(akfn,dat)
	result=read_ncdf(filelist(n),dat)
;------------------------------------------
;	s=size(dat.latitude)
	nprof=n_elements(dat.latitude)
	akmatrix=dat.tak; averaging kernel [10 x 10 x 30 x 4]
	akmatrix2=dat.tak2; averaging kernel [10 x 10 x 30 x 4]
        qf=dat.qcmask; [30 x 4]
	lats=dat.latitude; [30 x 4]
	lons=dat.longitude; [30 x 4]

; define output array
	if n eq 0 then begin
		akout=fltarr(aknlev,nprof*nfiles)*!Values.F_NAN
		akout2=fltarr(aknlev,nprof*nfiles)*!Values.F_NAN
		dofout=fltarr(nprof*nfiles)*!Values.F_NAN
		dofout2=fltarr(nprof*nfiles)*!Values.F_NAN
	endif

; make geographic subset
	gidx=where(lats lt zmax and lats gt zmin)
	lats=lats(gidx)
	lons=lons(gidx)
	akmatrix=akmatrix(*,*,gidx)
	akmatrix2=akmatrix2(*,*,gidx)
	qf=qf(gidx)
	nelem=n_elements(gidx)
; construct and apply a qc mask
	qualmask=fltarr(nelem)
	qualmask(where(qf eq 0))=1.0
	qualmask(where(qf gt 0))=!Values.F_NAN

; subset ak for specific pressure level
	for i=0,nelem-1 do begin
		akout(*,cnt)=diag_matrix(akmatrix(*,*,i))*qualmask(i)
		akout2(*,cnt)=diag_matrix(akmatrix2(*,*,i))*qualmask(i)
		cnt=cnt+1
	endfor
endfor

cntclim=0

help,akout
print,'count=',cnt
dofout=fltarr(nprof*nfiles)
dofout2=fltarr(nprof*nfiles)

akout(where(akout lt -100))=!Values.F_NAN
akout2(where(akout2 lt -100))=!Values.F_NAN

for i=0,cnt-1 do dofout(i)=total(akout(*,i),/nan)
for i=0,cnt-1 do dofout2(i)=total(akout2(*,i),/nan)

idx=where(dofout gt 0)
avgdof=round(mean(dofout(idx),/nan)*1000.)/1000.
avgdof=strtrim(avgdof,1)
avgdof=strmid(avgdof,0,4)

idx=where(dofout2 gt 0)
avgdof2=round(mean(dofout2(idx),/nan)*1000.)/1000.
avgdof2=strtrim(avgdof2,1)
avgdof2=strmid(avgdof2,0,4)

figtit=strupcase(xtype)+'CAPS SNPP T Avg Kernel for '+zonestr
figtit=zonestr
akmean=fltarr(aknlev)
akmean2=fltarr(aknlev)
; calculate mean and stddev of AK profile
for i=0,aknlev-1 do begin
	idx=where(abs(akout(i,*)) gt 0) 
	akmean(i)=mean(akout(i,idx))	
	idx=where(abs(akout2(i,*)) gt 0) 
	akmean2(i)=mean(akout2(i,idx))	
endfor
print,akmean
print,akmean2
; plot
tit2='T2, DFS='+avgdof2
tit='T1, DFS='+avgdof
zeroline=fltarr(aknlev)
a1=plot(akmean,akplev,'-b3',Ytitle='Pressure [hPa]',$
	/ylog,yrange=yrange,name=tit,font_size=15,$
	/buffer,Xtitle=xtitle,Title=figtit,$
	dimensions=[550,900]);,errorbar_linestyle=1,$
	;ytickname=['10','70','100','300','500'],$
	;yminor=-1)
a1.xrange=xrange
a1.xgridstyle=1
a1.xminor=0
a1.yminor=0
a1.ygridstyle=1
a1.ysubgridstyle=1
a1.yticklen=1
a1.xticklen=1
a1.ytickvalues=yticks
a2=plot(akmean2,akplev,color='deep pink',$
	/ylog,/overplot,name=tit2,$
	thick=3)
;l = legend(target=[a1,a2],position=[0.85,0.25])
l = legend(target=[a1,a2],/data,position=[0.15,15],shadow=0,font_size=13)
p=plot(zeroline,akplev,/buffer,/current,/overplot,$
	linestyle=1,color='gray')
a1.save,jname,resolution=120
print,'figure saved to '+jname

end
