pro nsplot_ak_diag_errorplot_tmp5,datestr,fnstr,izone

; fnstr='nucaps_pm_npp.fsr_tmp5_base'
; fnstr='nucaps_pm_npp.fsr_tmp5_lwmw'
; fnstr='nucaps_pm_npp.fsr_tmp5_mwsw'

; Nadia Smith
; Sep 2019
; Routine to plot Averaging kernel diagonals from netcdf files created by 
; ~/idl/postprocess/calc_climcaps_ak_allgases.pro
; 
; Output file structure:
;   LATITUDE        FLOAT     Array[1350]
;   LONGITUDE       FLOAT     Array[1350]
;   QCMASK          FLOAT     Array[1350]
;   AIR_TEMP_AVE_KERN   FLOAT     Array[1350, 23, 23]
;   H2O_VAP_AVE_KERN    FLOAT     Array[1350, 11, 11]
;   CO_AVE_KERN     FLOAT     Array[1350, 9, 9]
;   CO2_AVE_KERN    FLOAT     Array[1350, 8, 8]
;   CH4_AVE_KERN    FLOAT     Array[1350, 11, 11]
;   HNO3_AVE_KERN   FLOAT     Array[1350, 8, 8]
;   O3_AVE_KERN     FLOAT     Array[1350, 9, 9]
;   AIR_TEMP_FUNC_INDXS INT       Array[23]
;   H2O_VAP_FUNC_INDX   INT       Array[11]
;   CO_FUNC_INDXS   INT       Array[9]
;   CO2_FUNC_INDXS  INT       Array[8]
;   CH4_FUNC_INDXS  INT       Array[11]
;   HNO3_FUNC_INDXS INT       Array[8]
;   O3_FUNC_INDXS   INT       Array[9]
;   AIR_TEMP_FUNC_PRES   FLOAT     Array[23]
;   H2O_VAP_FUNC_PRES    FLOAT     Array[11]
;   CO_FUNC_PRES    FLOAT     Array[9]
;   CO2_FUNC_PRES   FLOAT     Array[8]
;   CH4_FUNC_PRES   FLOAT     Array[11]
;   HNO3_FUNC_PRES  FLOAT     Array[8]
;   O3_FUNC_PRES    FLOAT     Array[9]
;   AIR_TEMP_FUNC_LAST_INDX INT       Array[1350]
;   H2O_VAP_FUNC_LAST_INDX  INT       Array[1350]
;   CO_FUNC_LAST_INDX       INT       Array[1350]
;   CO2_FUNC_LAST_INDX      INT       Array[1350]
;   CH4_FUNC_LAST_INDX      INT       Array[1350]
;   HNO3_FUNC_LAST_INDX     INT       Array[1350]
;   O3_FUNC_LAST_INDX       INT       Array[1350]
;   AIR_TEMP_BOT_FUNC_PRES_EFF  FLOAT     Array[1350]
;   H2O_VAP_BOT_FUNC_PRES_EFF FLOAT     Array[1350]
;   CO_BOT_FUNC_PRES_EFF    FLOAT     Array[1350]
;   CO2_BOT_FUNC_PRES_EFF   FLOAT     Array[1350]
;   CH4_BOT_FUNC_PRES_EFF   FLOAT     Array[1350]
;   HNO3_BOT_FUNC_PRES_EFF  FLOAT     Array[1350]
;   O3_BOT_FUNC_PRES_EFF    FLOAT     Array[1350]
; 
; ------------------------------------------------
; 
; Extract date
yy=strmid(datestr,0,4)
mm=strmid(datestr,4,2)
dd=strmid(datestr,6,2)

; Extract relevant substrings from fnstr
; typical fnstr looks like this: 'nucaps_pm_npp.fsr_tmp5_lwmw'
xtype=strmid(fnstr,0,2)
orbit='pm'
o=strpos(fnstr,'_am_')
if o ge 0 then orbit='am'
sattype='npp.fsr'
o=strpos(fnstr,sattype)
regtype=strmid(fnstr,o+strlen(sattype)+1,9)

; Data directory
ddir='/peate_sci/nadias/ak/'+yy+'/'+mm+'/'+dd+'/'

collist=['spring green','forest green','orange red','salmon','cornflower']
collist=['deep pink','orchid','dark orange','royal blue','blue','blue']
; filename structure: nucaps_pm_npp_s201804010853590_e201804010859570_AK.nc
; Get file list
filespec=ddir+fnstr+'*noMW_noqc.nc'
filelist=findfile(filespec)
nfiles=n_elements(filelist)

; List of parameters to plot
paramlist=['air_temp','h2o_vap'];,'o3','co','ch4','co2','hno3']
nparam=n_elements(paramlist)
xnamelist=['T','H!I2!NO'];,'O!I3!N','CO','CH!I4!N','CO!I2!N','HNO!I3!N']

; Set up latitude zones
platmin=[-90.,-60.,-30.,30.,60.,-90]
platmax=[-60.,-30.,30.,60.,90.,90.]
zonelist=['S-Polar','S-Midlat','Tropics','N-MidLat','N-Polar','Global']
nzones=n_elements(zonelist)

; =======================================
; Loop over files and assemble arrays
; =======================================
cnt=0L
cntobs=0L
for ifile=0,nfiles-1 do begin
; Open AK file
	fn=filelist(ifile)
	print,'processing ',fn
	out=read_ncdf(fn,dat)
; Define arrays
        if ifile eq 0 then begin
		nobs=n_elements(dat.latitude)
		for ip=0,nparam-1 do begin
			param=paramlist(ip)
			out=execute('nlev_'+param+'=n_elements(dat.'+param+'_FUNC_PRES)'); nlev
			out=execute('plev_'+param+'=dat.'+param+'_FUNC_PRES'); plev
                	totobs=ulong(nobs)*ulong(nfiles)
			print,totobs
                	plat=fltarr(totobs)
			out=execute('ak_'+param+'=fltarr(totobs,nlev_'+param+')'); ak
		endfor; loop over parameters
        endif; first file check
; Populate ak, plat, plon arrays
	for iobs=0,nobs-1 do begin 
		plat(cntobs)=dat.latitude(iobs)
		ak_air_temp(cntobs,*)=diag_matrix(reform(dat.air_temp_ave_kern(iobs,*,*)))
;		ak_co(cntobs,*)=diag_matrix(reform(dat.co_ave_kern(iobs,*,*)))
;		ak_co2(cntobs,*)=diag_matrix(reform(dat.co2_ave_kern(iobs,*,*)))
;		ak_ch4(cntobs,*)=diag_matrix(reform(dat.ch4_ave_kern(iobs,*,*)))
		ak_h2o_vap(cntobs,*)=diag_matrix(reform(dat.h2o_vap_ave_kern(iobs,*,*)))
;		ak_o3(cntobs,*)=diag_matrix(reform(dat.o3_ave_kern(iobs,*,*)))
;		ak_hno3(cntobs,*)=diag_matrix(reform(dat.hno3_ave_kern(iobs,*,*)))
		cntobs=cntobs+1L
	endfor; loop over iobs
	cnt=cnt+iobs
	print,cntobs
endfor; loop over files

; replace fill values with nan
ak_air_temp(where(ak_air_temp le -999.))=!Values.F_NAN
ak_h2o_vap(where(ak_h2o_vap le -999.))=!Values.F_NAN
;ak_co2(where(ak_co2 le -999.))=!Values.F_NAN
;ak_hno3(where(ak_hno3 le -999.))=!Values.F_NAN
;ak_o3(where(ak_o3 le -999.))=!Values.F_NAN
;ak_ch4(where(ak_ch4 le -999.))=!Values.F_NAN
;ak_co(where(ak_co le -999.))=!Values.F_NAN
;

; Now you need to extract the different lat/lon zones and make averages
; define mean arrays
for ip=0,nparam-1 do begin
	out=execute('mak_'+paramlist(ip)+'=fltarr(nzones,nlev_'+paramlist(ip)+')')
	out=execute('sak_'+paramlist(ip)+'=fltarr(nzones,nlev_'+paramlist(ip)+')')
endfor; loop over params
; loop over zones and parameters
for iz=0,nzones-1 do begin
	print,'Calculating average for ',zonelist(iz)
	idx=where(plat ge platmin(iz) and plat lt platmax(iz))
	for ip=0,nparam-1 do begin
		param=paramlist(ip)
		out=execute('nlev=nlev_'+param)
		mak=fltarr(nlev)
		sak=fltarr(nlev)
		out=execute('ak=ak_'+param)
		for ilev=0,nlev-1 do mak(ilev)=mean(ak(idx,ilev),/nan)
		for ilev=0,nlev-1 do sak(ilev)=stddev(ak(idx,ilev),/nan)
		out=execute('mak_'+param+'(iz,*)=mak')
		out=execute('sak_'+param+'(iz,*)=sak')
	endfor; loop over paramlist
endfor; loop over zones

; ============================================
; READY TO PLOT
; ============================================
; plot nparam panels on a single figure
akrange=[-0.06,0.55]
figdim=[180,200]
xticks=[0.0,0.15,0.3,0.45]
yrange=[1000.,10.]
yticks=[1000,500,300,100,50,10]
ytickname=['1000.','500.','300.','100.','50.','10.']
figtit=strupcase(xtype+'caps-'+sattype)+' '+datestr+'–'+orbit+' mean averaging kernel diagonals for '+zonelist(izone)
;for ip=0,nparam-1 do begin
	ip=0
	param=paramlist(ip)
	xtit=xnamelist(ip)
	out=execute('plev=plev_'+param); nlev
	out=execute('mak=mak_'+param); nzone x nlev
	out=execute('sak=sak_'+param); nzone x nlev
	a=errorplot(mak(izone,*),plev,sak(izone,*),fltarr(n_elements(plev)),$;ytitle='Pressure [hPa]',$
        /ylog,yrange=yrange,xtitle=xtit+' Ave Kern',font_size=4,$
        /buffer,errorbar_color=collist(izone),margin=[0.18,0.1,0.1,0.1],$; left bottom right top
        color=collist(izone),thick=1.5,dimensions=figdim,layout=[nparam,1,ip+1],$
	errorbar_linestyle=0,errorbar_thick=0.5)
        a.xrange=akrange
        a.xgridstyle=1
        a.xthick=0.2
        a.ythick=0.2
        a.xminor=0
        a.yminor=0
	a.xtickfont_size=4
        a.ytickfont_size=4
        a.ygridstyle=1
        a.ysubgridstyle=1
        a.yticklen=1
        a.xticklen=1
        a.ytickvalues=yticks
        a.xtickvalues=xticks

for ip=1,nparam-1 do begin
	figtit=''
	if ip eq 3 then figtit=strupcase(xtype+'caps-'+sattype)+' '+datestr+'–'+orbit+' mean averaging kernel diagonals for '+zonelist(izone)
        param=paramlist(ip)
	aktit=xnamelist(ip)+' Ave Kern'
        out=execute('plev=plev_'+param); nlev
        out=execute('mak=mak_'+param); nzone x nlev
        out=execute('sak=sak_'+param); nzone x nlev
	print,izone
        a=errorplot(mak(izone,*),plev,sak(izone,*),fltarr(n_elements(plev)),$;ytitle='Pressure [hPa]',$
        /ylog,yrange=yrange,xtitle=aktit,font_size=5,$
        /buffer,errorbar_color=collist(izone),/current,Title=figtit,margin=[0.18,0.1,0.1,0.1],$; left bottom right top
        color=collist(izone),thick=1.5,dimensions=figdim,layout=[nparam,1,ip+1],$
	        errorbar_linestyle=0,errorbar_thick=0.5)
        a.xrange=akrange
        a.xgridstyle=1
        a.xthick=0.2
        a.ythick=0.2
	a.xtickfont_size=4
	a.ytickfont_size=4	
        a.xminor=0
        a.yminor=0
        a.ygridstyle=1
        a.ysubgridstyle=1
        a.yticklen=1
        a.xticklen=1
        a.ytickvalues=yticks
        a.xtickvalues=xticks
endfor; loop over paramlist
; Output plot filename
jname=fnstr+'_'+datestr+'_AKdiag_error_'+zonelist(izone)+'.jpg'
a.save,jname

print,'figure saved to '+jname


end
