pro nsplot_ak_indiv_fig2,datestr,sattype,orbit,xtype,izone
; Nadia Smith
; nadias@stcnet.com
; 
; ===========================================
; plot granules
; ===========================================
fillval=-999.
nan=!Values.F_NAN

; List of parameters to plot
paramlist=['air_temp','h2o_vap','o3','co','ch4','co2','hno3']
xnamelist=['T','H!I2!NO','O!I3!N','CO','CH!I4!N','CO!I2!N','HNO!I3!N']
nparam=n_elements(paramlist)

; Set up latitude zones
platmin=[-90.,-60.,-30.,30.,60.]
platmax=[-60.,-30.,30.,60.,90.]
zonelist=['S-Polar','S-Midlat','Tropics','N-MidLat','N-Polar']
nzones=n_elements(zonelist)

; Extract date
yy=strmid(datestr,0,4)
mm=strmid(datestr,4,2)
dd=strmid(datestr,6,2)

; Data directory
ddir='/peate_sci/nadias/ak/'+yy+'/'+mm+'/'+dd+'/'

; Get file list
filespec=ddir+xtype+'caps_'+orbit+'_'+sattype+'*.nc'
filelist=findfile(filespec)
nfiles=n_elements(filelist)

;paramlist=['air_temp','h2o_vap','co','co2','ch4','hno3','o3']
imaxlist=[0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5]


; Calculate mean Ave Kern for latitudinal zones
cntobs=0L
cntfile=0L
for ifile=0,nfiles-1 do begin
; Open AK file
        fn=filelist(ifile)
        print,'processing ',fn
        out=read_ncdf(fn,dat)
; Define arrays
        if ifile eq 0 then begin
                nobs=n_elements(dat.latitude)
                for ip=0,nparam-1 do begin
                        param=paramlist(ip)
                        out=execute('nlev_'+param+'=n_elements(dat.'+param+'_FUNC_PRES)'); nlev
                        out=execute('plev_'+param+'=dat.'+param+'_FUNC_PRES'); plev
            ;            totobs=ulong(nobs)*ulong(nfiles)
            ;            print,totobs
            ;            plat=fltarr(totobs)
            ;            out=execute('ak_'+param+'=fltarr(totobs,nlev_'+param+',nlev_'+param+')'); ak=[nobs x nlev x nlev]
                        out=execute('ak_'+param+'=fltarr(nlev_'+param+',nlev_'+param+')'); ak=[nobs x nlev x nlev]
                        out=execute('cnt_'+param+'=fltarr(nlev_'+param+',nlev_'+param+')'); ak=[nobs x nlev x nlev]
                endfor; loop over parameters
        endif; first file check
; Populate ak, plat, plon arrays
; check if granule falls intarget zone
; add matrices together, keep count
	help,ak_air_temp
	print,nlev_air_temp	
	plat=dat.latitude
	idx=where(plat ge platmin(izone) and plat lt platmax(izone))  
	if n_elements(idx) gt 1 then begin; at least half the granule should be in zone 
; loop over parameters
		for ip=0,nparam-1 do begin
			param=paramlist(ip)
			out=execute('nlev=nlev_'+param)
			out=execute('ak=reform(dat.'+param+'_ave_kern(idx,*,*))')
			ak(where(ak le fillval))=nan
; now loop over levels and add together
			for ilev=0,nlev-1 do begin
			for jlev=0,nlev-1 do begin
				val=reform(ak(*,ilev,jlev))
				validx=where(val gt -1)
				val=val(validx)
		;		print,n_elements(validx),ilev,jlev
				out=execute('ak_'+param+'(ilev,jlev)=ak_'+param+'(ilev,jlev)+total(val,/nan)')
				out=execute('cnt_'+param+'(ilev,jlev)=cnt_'+param+'(ilev,jlev)+n_elements(validx)')
			endfor; loop over jlev
			endfor; loop over ilev
		endfor; loop over paramlist
        endif; zone test
endfor; loop over files

; calculate average
for ip=0,nparam-1 do begin
	param=paramlist(ip)
	out=execute('ak=ak_'+param)
	out=execute('nlev=nlev_'+param)
	out=execute('cnt=cnt_'+param)
	for ilev=0,nlev-1 do begin
	for jlev=0,nlev-1 do begin
		ak(ilev,jlev)=ak(ilev,jlev)/cnt(ilev,jlev)
	endfor
	endfor
	out=execute('mak_'+param+'=ak')
endfor; loop over paramlist
; Now you need to extract the different lat/lon zones and make averages
; define mean arrays
; =====================================
; start plotting
; =====================================

; Loop over paramlist 
; for each parameter, calculate the mean and std for error plots
;for ip=0,n_elements(paramlist)-1 do begin
; PLOT TEMPERATURE
	ip=0
	imax=imaxlist(ip)
	param=paramlist(ip)
	xtit=xnamelist(ip)
	out=execute('nlev=nlev_'+param)
	out=execute('plev=plev_'+param)
	out=execute('mak=mak_'+param)
	dof=total(diag_matrix(mak),/nan)
	dofstr=string(round(dof*100)/100., format='(f4.2)')
; Now you can plot the mean and stdev profiles
; setup plot
	rgb=colortable(['tomato','medium blue'],ncolors=nlev)
	akrange=[-0.06,0.5]
	xticks=[0.0,0.15,0.3,0.45]
	yrange=[1000.,10.]
	yticks=[1000,500,300,100,50,10]
	ytickname=['1000.','500.','300.','100.','50.','10.']
	figtit=strupcase(xtype)+'CAPS-'+strupcase(sattype)+' '+datestr+' '+orbit+' mean averaging kernels for '+zonelist(izone)+' zone'
; loop over levels
	for ilev=0,nlev-1 do begin
		ak=reform(mak(ilev,*))	
		if ilev eq 0 then begin
			a=plot(ak,plev,$
        		/ylog,yrange=yrange,xtitle=xtit+' Ave Kernels',font_size=5,$
        		/buffer,margin=[0.18,0.1,0.1,0.1],Title='',$
        		color=reform(rgb(ilev,*)),thick=0.5,dimensions=[600,200],layout=[nparam,1,ip+1])
			a.xrange=akrange
			a.xgridstyle=1
			a.xminor=0
			a.yminor=0
                        a.ythick=0.2
                        a.xthick=0.2
	        	a.xtickfont_size=4
		        a.ytickfont_size=4
			a.ygridstyle=1
			a.ysubgridstyle=1
			a.yticklen=1
			a.xticklen=1
			a.xtickvalues=xticks
			a.ytickvalues=yticks
		endif else begin; test if first file
			a=plot(ak,plev,color=reform(rgb(ilev,*)),$
        		/buffer,/overplot,thick=0.5)
		endelse
	endfor; loop over trapezoide levels
;	t2=text(0.2,15,strtrim(nlev,1)+' Ave Kernels',target=a,/data,font_size=3,font_color='medium blue')
;	t3=text(0.2,20,dofstr+' DOFS',/data,target=a,font_size=3,font_color='medium blue')
; paramlist=['air_temp','h2o_vap','co','co2','ch4','hno3','o3']

; PLOT THE GASES
for ip=1,n_elements(paramlist)-1 do begin
        imax=imaxlist(ip)
        param=paramlist(ip)
	xtit=xnamelist(ip)
        out=execute('nlev=nlev_'+param)
        out=execute('plev=plev_'+param)
        out=execute('mak=mak_'+param)
        dof=total(diag_matrix(mak),/nan)
        dofstr=string(round(dof*100)/100., format='(f4.2)')
; Now you can plot the mean and stdev profiles
; setup plot
	rgb=colortable(['tomato','medium blue'],ncolors=nlev)
        akrange=[-0.06,0.5]
        yrange=[1000.,10.]
	xticks=[0.0,0.15,0.3,0.45]
        yticks=[1000,500,300,100,50,10]
        ytickname=['1000.','500.','300.','100.','50.','10.']
        figtit=strupcase(xtype)+'CAPS-'+strupcase(sattype)+' '+datestr+' '+orbit+' mean averaging kernels for '+zonelist(izone)+' zone'
; loop over levels
	if ip ne 3 then begin
        for ilev=0,nlev-1 do begin
                ak=reform(mak(ilev,*))
                if ilev eq 0 then begin
                        a=plot(ak,plev,$
                        /ylog,yrange=yrange,xtitle=xtit+' Ave Kernels',font_size=5,$
                        /buffer,/current,margin=[0.18,0.1,0.1,0.1],$
                        color=0B,thick=0.5,dimensions=[600,200],layout=[nparam,1,ip+1])
                        a.xrange=akrange
                        a.xgridstyle=1
			a.ythick=0.2
			a.xthick=0.2
                        a.xminor=0
                        a.yminor=0
                        a.xtickfont_size=4
                        a.ytickfont_size=4
                        a.ygridstyle=1
                        a.ysubgridstyle=1
                        a.yticklen=1
                        a.xticklen=1
			a.xtickvalues=xticks;[0.0,0.15,0.3,0.45]
                        a.ytickvalues=yticks
;			a.ytitle='Pressure [hPa]'
                endif else begin; test if first file
                        a=plot(ak,plev,color=reform(rgb(ilev,*)),$
                        /buffer,/overplot,thick=0.5)
                endelse
        endfor; loop over trapezoide levels
;        t2=text(0.2,15,strtrim(nlev,1)+' Ave Kernels',/data,target=a,font_size=3,font_color='medium blue')
;        t3=text(0.2,20,dofstr+' DOFS',target=a,/data,font_size=3,font_color='medium blue')
	endif else begin
        for ilev=0,nlev-1 do begin
                ak=reform(mak(ilev,*))
                if ilev eq 0 then begin
                        a=plot(ak,plev,$
                        /ylog,yrange=yrange,xtitle=xtit+' Ave Kernels',font_size=5,$
                        /buffer,/current,margin=[0.18,0.1,0.1,0.1],title=figtit,$
                        color=reform(rgb(ilev,*)),thick=0.5,dimensions=[600,200],layout=[nparam,1,ip+1])
                        a.xrange=akrange
                        a.xgridstyle=1
                        a.ythick=0.2
                        a.xthick=0.2
                        a.xminor=0
                        a.yminor=0
                        a.xtickfont_size=4
                        a.ytickfont_size=4
                        a.ygridstyle=1
                        a.ysubgridstyle=1
                        a.yticklen=1
                        a.xticklen=1
			a.xtickvalues=xticks
                        a.ytickvalues=yticks
		;	a.ytitle='Pressure [hPa]'
                endif else begin; test if first file
                        a=plot(ak,plev,color=reform(rgb(ilev,*)),$
                        /buffer,/overplot,thick=0.5)
                endelse
        endfor; loop over trapezoide levels
;        t2=text(0.2,15,strtrim(nlev,1)+' Ave Kernels',target=a,/data,font_size=3,font_color='medium blue')
;        t3=text(0.2,20,dofstr+' DOFS',target=a,/data,font_size=3,font_color='medium blue')
	endelse

endfor ; loop over paramlist
jname=xtype+'caps_'+sattype+'_ind_ave_kern_'+datestr+orbit+'_'+zonelist(izone)+'.jpg'
a.save,jname
print,'figure saved to '+jname


end
