pro nsplot_ak_indiv_paper_fig1,datestr,sattype,orbit,xtype,ifile
; Nadia Smith
; nadias@stcnet.com
; 
; =====================================================
; plot individual AKs one retrieval footprint at a time
; =====================================================
fillval=-999.
nan=!Values.F_NAN

; List of parameters to plot
paramlist=['air_temp','h2o_vap']
xnamelist=['T','H!I2!NO']
nparam=n_elements(paramlist)


; Extract date
yy=strmid(datestr,0,4)
mm=strmid(datestr,4,2)
dd=strmid(datestr,6,2)

; Data directory
ddir='/peate_sci/nadias/ak/'+yy+'/'+mm+'/'+dd+'/'

; Get file list
filespec=ddir+xtype+'caps_'+orbit+'_'+sattype+'*.nc'
filelist=findfile(filespec)
nfiles=n_elements(filelist)

;paramlist=['air_temp','h2o_vap','co','co2','ch4','hno3','o3']
imaxlist=[0.5,0.5]

; load black and white colorbar
; Extract 5 footprints along a single scanline with nadir at the center
; Open AK file
        fn=filelist(ifile)
        print,'processing ',fn
        out=read_ncdf(fn,dat)
; Define arrays 
        nobs=n_elements(dat.latitude)
        for ip=0,nparam-1 do begin
              param=paramlist(ip)
              out=execute('nlev_'+param+'=n_elements(dat.'+param+'_FUNC_PRES)'); nlev
              out=execute('plev_'+param+'=dat.'+param+'_FUNC_PRES'); plev
        endfor; loop over parameters
; Populate ak, plat, plon arrays
; check if granule falls intarget zone
; add matrices together, keep count
	;idx=[11,13,15,17,19]; 5 scenes across first scanline
	idx=[111,333,555,777,999]; 5 scenes across first scanline
	nfoot=n_elements(idx)
	plat=dat.latitude(idx)
	plon=dat.longitude(idx)
	ak=reform(dat.air_temp_ave_kern(idx,*,*))
	ak(where(ak le fillval))=nan
	ak_air_temp=ak; ak_air_temp, ak_wat_vap
        ak=reform(dat.h2o_vap_ave_kern(idx,*,*))
        ak(where(ak le fillval))=nan
        ak_h2o_vap=ak; ak_air_temp, ak_wat_vap
; Now you need to extract the different lat/lon zones and make averages
; define mean arrays
; =====================================
; start plotting
; =====================================
; PLOT TOP ROW: TEMPERATURE
for ip=0,1 do begin
	imax=imaxlist(ip)
	param=paramlist(ip)
	xtit=xnamelist(ip)
	out=execute('nlev=nlev_'+param)
	out=execute('plev=plev_'+param)
	out=execute('ak0=ak_'+param); [nfoot x nlev x nlev]
	rgb=colortable(['tomato','medium blue'],ncolors=nlev)
; Now you can plot the mean and stdev profiles
; setup plot
	akrange=[-0.03,0.3]
	;akrange=[-0.15,0.45]
	;xticks=[0.0,0.15,0.3,0.45]
	xticks=[0.0,0.1,0.2,0.3]
	yrange=[1000.,10.]
	yticks=[1000,500,300,100,50,10]
	ytickname=['1000.','500.','300.','100.','50.','10.']
; plot all the averaging kernels
for ifoot=0,nfoot-1 do begin; loop over scenes	
	figtit='lat/lon=['+string(plat(ifoot),format='(f6.1)')+','+$
		string(plon(ifoot),format='(f6.1)')+']'
                figcnt=(ifoot+1)+(nfoot*ip)
                print,'plotting figure',figcnt
	ilev=0
	ak=reform(ak0(ifoot,ilev,*))
	if figcnt eq 1 then begin		
		a=plot(ak,plev,$
	        /ylog,yrange=yrange,xtitle=xtit+' Ave Kernels',font_size=5,$
        	/buffer,margin=[0.18,0.1,0.1,0.1],Title=figtit,$
	        color=reform(rgb(ilev,*)),thick=0.5,dimensions=[600,400],layout=[nfoot,2,figcnt])
	endif else begin
	        a=plot(ak,plev,$
	        /ylog,yrange=yrange,xtitle=xtit+' Ave Kernels',font_size=5,$
        	/buffer,/current,margin=[0.18,0.1,0.1,0.1],Title=figtit,$
	        color=reform(rgb(ilev,*)),thick=0.5,dimensions=[600,400],layout=[nfoot,2,figcnt])
        endelse
;	if figcnt ne 1 and figcnt ne 6 then a.ytitle='Pressure [hPa]'
	if figcnt eq 1 or figcnt eq 6 then a.ytitle='Pressure [hPa]'
		a.xrange=akrange
	        a.xgridstyle=1
        	a.xminor=0
	        a.yminor=0
        	a.ythick=0.2
	        a.xthick=0.2
        	a.xtickfont_size=4
	        a.ytickfont_size=4
        	a.ygridstyle=1
	        a.ysubgridstyle=1
        	a.yticklen=1
	        a.xticklen=1
        	a.xtickvalues=xticks
	        a.ytickvalues=yticks
	for ilev=1,nlev-1 do begin
		ak=reform(ak0(ifoot,ilev,*))
		a=plot(ak,plev,color=reform(rgb(ilev,*)),$
        	/buffer,/overplot,thick=0.5)
	endfor
endfor; loop over ifoot

endfor ; loop over paramlist
jname=xtype+'caps_'+sattype+'_ind_ave_kern_'+datestr+orbit+'_gran'+strtrim(ifile,1)+'.jpg'
a.save,jname
print,'figure saved to '+jname


end
