pro nsplot_ak_indiv_testgranules,type,ilon,ilat

; Nadia Smith
; nadias@stcnet.com
; 
; ===========================================
; plot granules
; ===========================================
ddir='/raid/evan/sndr/PostProc/test/outref/'

case type of 
	'airs': fn='SNDR.AQUA.AIRS.20160114T1005.m06.g101.L2_CLIMCAPS_RET.std.v00_00_00.j.180110183539.nc'
	'crimss': fn='SNDR.J1.CRIMSS.20190114T1000.m06.g101.L2_CLIMCAPS_RET.std.v02_15_00.j.190728000000.nc'
endcase
nfiles=5;
fillval=9.96921e+36
nan=!Values.F_NAN

figtit=strupcase(type)

;paramlist=['air_temp','h2o_vap','co','co2','ch4','hno3','o3']
imaxlist=[0.5,0.5,0.5,0.5,0.5]
paramlist=['air_temp','h2o_vap','co','ch4','o3']
;paramlist=['co','ch4','o3']
collist=['deep pink','fuchsia','medium orchid','violet','plum','rosy brown','tan','sandy brown',$
	'peru','chocolate','sienna','dark salmon','coral','tomato','orange red','dark orange',$
	'orange','goldenrod','dark goldenrod','gold','olive','olive drab','dark green','forest green',$
	'sea green','medium sea green','spring green','light green','aqua','light sea green']
print,n_elements(collist)
; extract date from filename
pos=strpos(fn,figtit)
len=strlen(figtit)
datestr=strmid(fn,pos+len+1,8)
print,'date is: '+datestr
yy=strmid(datestr,0,4)
mm=strmid(datestr,4,2)
dd=strmid(datestr,6,2)

; Find retrieval system name
pos1=strpos(fn,'L2_')+3
pos2=strpos(fn,'_RET')
sysname=strmid(fn,pos1,pos2-pos1)
print,'retrieval system is: '+sysname

; Find granule number
pos=strpos(fn,'.g')
gran=strmid(fn,pos+1,4)
print,'granule number: ',gran

; read the averaging kernel sub-group
grpname='ave_kern'
; *tmp,h2o_vap,ch4,co,co2,o3,hno3
; _func_pres_bnds [4 x nlev]
; _func_last_indx [nfor x nscan]
; _func_pres [nlev] 
; _ave_kern [nlev x nlev x nfor x nscan]

nsread_nc_group,[ddir+fn],grpname,grp

out=read_ncdf([ddir+fn],dat)
plat=string(round(dat.lat(ilon,ilat)*100)/100.,format='(f7.2)')
plon=string(round(dat.lon(ilon,ilat)*100)/100.,format='(f7.2)')
print,'['+plon+','+plat+']'
; =====================================
; start plotting
; =====================================

; Loop over paramlist 
; for each parameter, calculate the mean and std for error plots
; plot all 5 files on top of each other - another loop over files
for ip=0,n_elements(paramlist)-1 do begin
	imax=imaxlist(ip)
	param=paramlist(ip)
;	if ip eq 0 then str='qc=dat.'+param+'_qc'
;	if ip ge 1 then str='qc=dat.'+param+'_tot_qc'
;	void=execute(str); qc

; extract averaging kernel (AK) and effective pressure
	str='akgran=grp.'+param+'_ave_kern'
	void=execute(str); akgran=[nlev x nlev x nfor x nscan]
	str='plev=grp.'+param+'_func_pres/100.'; convert pressure from [Pa] to [hPa]
	void=execute(str); plev
	s=size(akgran)
        nfor=s(3)
        nscan=s(4)
        nlev=s(1)

; extract AKs for a single retrieval defined by [ilon,ilat]
	akmat=reform(akgran(*,*,ilon,ilat)); [nlev x nlev]
	idx=where(akmat eq fillval)
	akmat(idx)=nan
;        imax=max(akmat)+0.05
        xrange=[0,imax]
; Now you can plot the mean and stdev profiles
; setup plot
	yrange=[1000.,10.]
	yticks=[1000,500,300,100,50,10]
	ytickname=['1000.','500.','300.','100.','50.','10.']

; loop over levels
	for ilev=0,nlev-1 do begin
		ak=reform(akmat(ilev,*))	
		if ilev eq 0 then begin
			a=plot(ak,plev,ytitle='Pressure [hPa]',$
        		/ylog,yrange=yrange,xtitle=figtit+' Ave Kernels',font_size=12,$
        		/buffer,Title='CLIMCAPS - '+strupcase(param)+' - '+datestr+' - '+gran,$
        		color=collist(ilev),thick=3,dimensions=[480,900])
			a.xrange=xrange
			a.xgridstyle=1
			a.xminor=0
			a.yminor=0
			a.ygridstyle=1
			a.ysubgridstyle=1
			a.yticklen=1
			a.xticklen=1
			a.ytickvalues=yticks
		endif else begin; test if first file
			a=plot(ak,plev,color=collist(ilev),$
        		/buffer,/overplot,thick=3)
		endelse
	endfor; loop over trapezoide levels
	dofs=round(total(diag_matrix(akmat),/nan)*100)/100.
	dofstr=string(dofs,format='(F4.2)')
	t1=text(0.3,15,'['+plon+','+plat+']',/data,font_size=12,font_color='medium blue')
	t2=text(0.3,17.5,strtrim(nlev,1)+' x Trapozoids',/data,font_size=12,font_color='medium blue')
	t3=text(0.3,20,dofstr+' DOFS',/data,$
	font_size=12,font_color='medium blue')
; paramlist=['air_temp','h2o_vap','co','co2','ch4','hno3','o3']
        jname=figtit+'_'+param+'_AK.jpg'
        a.save,jname,resolution=120
        print,'figure saved to '+jname

endfor ; loop over paramlist

end
