; script by Nadia to read RAQMSi
pro nsplot_ak_profs,pval,instr,xtype,orbit,zone

idxak=[4, 5, 6, 7]; [100, 150, 200, 300]

o3plev=[0.026,22.16,53.79,74.35,106.586,146.781,217.685,307.015,606.847,1085.40]
akplev=o3plev(idxak)
aknlev=n_elements(o3plev)
pidx=idxak(pval)
; date
daystr='20180321'
datestr='20180321'
yy='2018';strmid(daystr,0,4)
mm='03';strmid(daystr,4,2)
dd='21';strmid(daystr,6,2)

;orbit='pm'
param='O3'

case zone of 
	0: begin
	zonestr='South Pole'
	zmin=-90
	zmax=-60
	end
	1: begin
	zonestr='South MidLat'
	zmin=-60
	zmax=-30
	end
	2: begin
	zonestr='Tropics'
	zmin=-30
	zmax=30
	end
	3: begin
	zonestr='North MidLat'
	zmin=30
	zmax=60
	end
	4: begin
	zonestr='North Pole'
	zmin=60
	zmax=90
	end
endcase

; data directory
ddir='/iliad/proxy/nadias/'+xtype+'caps/'+instr+'/'+yy+'/'+mm+'/'+dd+'/netcdf'

; output figure name
jname=xtype+'caps_'+instr+'_'+param+'_AK_profs_'+datestr+'_'+strtrim(floor(o3plev(pidx)),1)+'hPa_'+orbit+'_zone'+strtrim(zone,1)+'.jpg'

title=strupcase(xtype)+'CAPS-'+instr+' O3 AK at '+strtrim(floor(o3plev(pidx)),1)+' hPa '+datestr+' '+strupcase(orbit)+' orbit'

figtit=strupcase(xtype)+'CAPS-'+instr+' AK at '+strtrim(floor(o3plev(pidx)),1)+'hPa; '+zonestr+' Avg'

; find all the files to plot
filespec=ddir+'/'+xtype+'caps_'+instr+'_'+orbit+'_zone*'+datestr+'*_AK.nc'
print,filespec
filelist=findfile(filespec)
nfiles=n_elements(filelist)
print,strtrim(nfiles,1)+' files to process'

; start plotting
claser,psfile="unc.eps",/eps
loadct,20
mcolor=byte(!p.color)
if mcolor eq 0 then mcolor=255
icmm1=mcolor-1
icmm2=mcolor-2
!p.background=255.
!p.color=0
!p.thick=2.0
!p.charsize=1.5
loadct,20;33
cnt=0

;for n=0,100 do begin
for n=0,nfiles-1 do begin
    	print, 'reading file', filelist(n)
	result=read_ncdf(filelist(n),dat)
;------------------------------------------
;	s=size(dat.latitude)
	nprof=n_elements(dat.latitude)
;	nscan=s(2)
	akmatrix=dat.o3ak; averaging kernel [10 x 10 x 30 x 4]
        qf=dat.qcmask; [30 x 4]
	lats=dat.latitude; [30 x 4]
	lons=dat.longitude; [30 x 4]

; define output array
	if n eq 0 then akout=fltarr(aknlev,nprof*nfiles)*!Values.F_NAN
	;if n eq 0 then akout=fltarr(aknlev,nprof*nscan*nfiles)*!Values.F_NAN

; reshape arrays to simplify looping and subsetting
	;qf=reform(qf,nprof*nscan)	
        ;lats=reform(lats,nprof*nscan)
        ;lons=reform(lons,nprof*nscan)
	;print,aknlev
;	akmatrix=reform(akmatrix,aknlev,aknlev,nprof*nscan)

; make geographic subset
	gidx=where(lats lt zmax and lats gt zmin)
	lats=lats(gidx)
	lons=lons(gidx)
	akmatrix=akmatrix(*,*,gidx)
	qf=qf(gidx)
	nelem=n_elements(gidx)

; construct and apply a qc mask
	qualmask=fltarr(nelem)
	qualmask(where(qf eq 0))=1.0
	qualmask(where(qf gt 0))=!Values.F_NAN

; subset ak for specific pressure level
	for i=0,nelem-1 do begin
	        ;ak=reform(diag_matrix(akmatrix(*,*,i,j)))
		akout(*,cnt)=akmatrix(pidx,*,i)*qualmask(i)
		cnt=cnt+1
	endfor
	
endfor
help,akout
print,'count=',cnt
akout(where(akout lt -100))=!Values.F_NAN
akmean=fltarr(aknlev)
xerr=fltarr(aknlev)
zeroline=fltarr(aknlev)
; calculate mean and stddev of AK profile
for i=0,aknlev-1 do begin
	idx=where(abs(akout(i,*)) gt 0) 
	akmean(i)=mean(akout(i,idx))	
	xerr(i)=stddev(akout(i,idx))
endfor

; plot
a=errorplot(akmean,o3plev,xerr,[0],'-b3',Ytitle='Pressure [hPa]',$
	/ylog,yrange=[650.0,10.0],$
	/buffer,Xtitle='Averaging Kernel',Title=figtit,$
	dimensions=[500,800],errorbar_linestyle=1,$
	errorbar_color='tomato',errorbar_thick=3)
	;ytickname=['10','70','100','300','500'],$
	;yminor=-1)
a.xrange=[-0.05,0.3]
;a=plot(akmean-akstd,o3plev,'b*',/buffer,/current,/overplot)
a=plot(zeroline,o3plev,/buffer,/current,/overplot,$
	linestyle=1,color='gray')
a.save,jname,resolution=120
print,'figure saved to '+jname

end
