pro nsplot_ak_tests

; Nadia Smith
; nadias@stcnet.com
; 
; ===========================================
; plot granules
; ===========================================
ddir='/raid/evan/sndr/PostProc/test/outref/'

fn0='SNDR.AQUA.AIRS.20160114T1005.m06.g101.L2_CLIMCAPS_RET.std.v00_00_00.j.180110183539.nc'
fn1='SNDR.AQUA.AIRS_IM.20160114T1005.m06.g101.L2_CLIMCAPS_RET.std.v00_00_00.j.180110183539.nc'
fn2='SNDR.J1.CRIMSS.20190114T1000.m06.g101.L2_CLIMCAPS_RET.std.v02_15_00.j.190728000000.nc'
fn4='SNDR.SNPP.CRIMSS.20160114T1000.m06.g101.L2_CLIMCAPS_RET_NSR.std.v02_15_00.j.190128000000.nc'
fn3='SNDR.SNPP.CRIMSS.20160114T1000.m06.g101.L2_CLIMCAPS_RET.std.v02_15_00.j.190128000000.nc'

nfiles=5;
fillval=9.96921e+36
nan=!Values.F_NAN

; figure titles
fn0tit='AIRS-only'
fn1tit='AIRS+AMSU'
fn2tit='J1 FSR CrIS+ATMS'
fn4tit='SNPP NSR CrIS+ATMS'
fn3tit='SNPP FSR CrIS+ATMS'

paramlist=['air_temp','h2o_vap','co','co2','ch4','hno3','o3']
;paramlist=['h2o_vap']
collist=['spring green','forest green','orange red','salmon','cornflower']

; extract date from filename
pos=strpos(fn0,'AIRS')+5
datestr=strmid(fn0,pos,8)
print,'date is: '+datestr
yy=strmid(datestr,0,4)
mm=strmid(datestr,4,2)
dd=strmid(datestr,6,2)

; Find retrieval system name
pos1=strpos(fn1,'L2_')+3
pos2=strpos(fn1,'_RET')
sysname=strmid(fn1,pos1,pos2-pos1)
print,'retrieval system is: '+sysname

; Find granule number
pos=strpos(fn1,'.g')
gran=strmid(fn1,pos+1,4)
print,'granule number: ',gran

; read the averaging kernel sub-group
grpname='ave_kern'
; *tmp,h2o_vap,ch4,co,co2,o3,hno3
; _func_pres_bnds [4 x nlev]
; _func_last_indx [nfor x nscan]
; _func_pres [nlev] 
; _ave_kern [nlev x nlev x nfor x nscan]

for nf=0,nfiles-1 do begin
	num=strtrim(nf,1)
	str='nsread_nc_group,[ddir+'+'fn'+num+'],grpname,grp'+num
	void=execute(str); grp1/grp2/grp3/grp4/grp5
endfor ; loop over nfiles

; =====================================
; start plotting
; =====================================

; Loop over paramlist 
; for each parameter, calculate the mean and std for error plots
; plot all 5 files on top of each other - another loop over files
for ip=0,n_elements(paramlist)-1 do begin

	param=paramlist(ip)
; extract averaging kernel (AK) and effective pressure
	for nf=0,nfiles-1 do begin
		num=strtrim(nf,1)
		print,num,param
		str='dat'+num+'=grp'+num+'.'+param+'_ave_kern'
		void=execute(str); dat0/dat1/dat2/dat3/dat4
		str='plev'+num+'=grp'+num+'.'+param+'_func_pres/100.'; convert pressure from [Pa] to [hPa]
		void=execute(str); plev0/plev1/plev2/plev3/plev4
		if nf eq 0 then begin
		        s=size(dat0)
        		nfov=s(3)
        		nscan=s(4)
        		nlev=s(1)
		endif
		str='ak'+num+'=fltarr('+strtrim(nlev,1)+','+strtrim(nfov*nscan,1)+')'; AK
		void=execute(str)
		str='mak'+num+'=fltarr('+strtrim(nlev,1)+')'; mean of AK
		void=execute(str)
		str='sak'+num+'=fltarr('+strtrim(nlev,1)+')'; stdev of AK
		void=execute(str)
; extract AK diagonal for each FOR
		icnt=0
	        for ifov=0,nfov-1 do begin
        	        for iscan=0,nscan-1 do begin
			        i1=strtrim(ifov,1)
                	        i2=strtrim(iscan,1)
				ic=strtrim(icnt,1)
				str='dud=diag_matrix(reform(dat'+num+'(*,*,'+i1+','+i2+')))'
				void=execute(str)
				idx=where(dud eq fillval)
				dud(idx)=nan
				str='ak'+num+'(*,'+ic+')=dud'
				void=execute(str)
				icnt=icnt+1
                	endfor; loop over nscan
        	endfor; loop over ifov
; calculate mean and stndev
		for ilev=0,nlev-1 do begin
			str='d=moment(reform(ak'+num+'('+strtrim(ilev,1)+',*)),/nan)'
			void=execute(str); d(0) is mean, d(1) is variance
			str='mak'+num+'('+strtrim(ilev,1)+')=d[0]'
			void=execute(str); populate mak; mean ak
			str='sak'+num+'('+strtrim(ilev,1)+')=sqrt(d[1])'
			void=execute(str); populate sak; stdev ak
		endfor; loop over file
; Now you can plot the mean and stdev profiles
; setup plot
		xrange=[0.,0.5]
		yrange=[1000.,10.]
		yticks=[1000,500,300,100,50,10]
		ytickname=['1000.','500.','300.','100.','50.','10.']
	
		if nf ge 1 then	print,'mean ak ',mak0-mak1
		print,'eff pres ',plev0
		if nf eq 0 then begin
			a=errorplot(mak0,plev0,sak0,$;Ytitle='Pressure [hPa]',$
        		/ylog,yrange=yrange,xtitle='Mean Averaging Kernel',font_size=12,$
        		/buffer,Title='CLIMCAPS - '+strupcase(param)+' - '+datestr+' - '+gran,$
        		errorbar_linestyle=0,color=collist(nf),thick=3,$
        		errorbar_color=collist(nf),errorbar_thick=2,dimensions=[480,900])
			a.xrange=xrange
			a.xgridstyle=1
			a.xminor=0
			a.yminor=0
			a.ygridstyle=1
			a.ysubgridstyle=1
			a.yticklen=1
			a.xticklen=1
			a.ytickvalues=yticks
		endif else begin; test if first file
			str='dat=mak'+num
			void=execute(str)
			str='err=sak'+num
			void=execute(str)
			a=errorplot(dat,plev0,err,$
        		/buffer,/overplot,color=collist(nf),thick=3,$
        		errorbar_color=collist(nf),errorbar_thick=2)
		endelse
		str='a'+num+'=a'
		void=execute(str)
	endfor; loop over files
; paramlist=['air_temp','h2o_vap','co','co2','ch4','hno3','o3']
	if ip eq 0 then pos=[0.5,180]; temperature
	if ip eq 1 or ip eq 2 or ip eq 3 or ip eq 4 then pos=[0.5,20]; H2O
	if ip eq 6 then pos=[0.5,350]; O3
	if ip eq 5 then pos=[0.5,200]; HNO3
	l=legend(target=[a0,a1,a2,a3,a4],/data,position=pos,$
		label=[fn0tit,fn1tit,fn2tit,fn3tit,fn4tit])
        jname='test_'+param+'_AK.jpg'
        a.save,jname,resolution=120
        print,'figure saved to '+jname
; Now plot the trapezoids


endfor ; loop over paramlist

end
