pro calc_totcd,cdprof,duflag,totcd

; routine to calculate total column densities from trace gas profiles
; this routine assumes that the surface layer has been treated correctly
; i.e., that BLMULT has been applied
; input: 
;   cdprof – column density profile in [molec/cm2] [size=nlev]
;   duflag – dobson units flag [1=yes convert to DU, 0=no]
; output:
;   totcd – total column trace gas value [size=1]
; 
; Nadia Smith
; STC / NOAA JPSS Affiliate
; nadias@stcnet.com
; ------------------

; get size of array
  nlev=n_elements(cdprof)

; define constants
  navog=6.02214199e+23; NIST Avogadro's number (molec/mole)
  nloschmidt= 2.6867775E+19; NIST Loschmidt's molec/cm^3 per atm @ std pressure
  mw_wv=18.0151; g/mole water

; initialize output value
  totcd=0.0

; sum all column density (cd) layers
  for L=0L,nlev-1 do begin
    totcd = totcd + cdprof(L) ; sum layer cd's in molec/cm2
  endfor

; Now convert based on value in duflag
  if duflag eq 1 then begin ; ozone total column in [DU]
     totcd = totcd*1000.0/nloschmidt ; total column ozone in [DU]
  endif else begin ; total precipitable water in [cm]
     totcd = totcd*mw_wv/navog; [g/cm^2] or [cm]
; note: TPW/totwat is in g/cm2, density of water is 1.0g/cm3 which is equal to 1 cm of water
  endelse
end
