pro call_aggreg_interpol,xtype,instr,orbit,qflag,outfn
;orbit='pm' or 'am'
capstype=xtype+'caps'

; vertical interpolation
; aggregation of granules

; Routine to vertically interpolate NUCAPS retrieval profiles
; from 100 native pressure grid to standard NWP levels used in AWIPS-II

; Nadia Smith, nadias@stcnet.com
; JPSS Sounding Subject Matter Expert
; July, 13 2018
 
; infn = NUCAPS EDR filename and full path
; outfn = netcdf filename of output variables
; 
; qflag = 0 means apply qc
; qflag = 1 means do not apply qc
;
; ============= END HEADER ===============

 fill_val=-9999.0
 fillval=!Values.F_NAN
; define standard NWP pressure levels
; the NUCAPS retrieval profiles will be interpolated to these values
; these are the levels to interpolate to
  stdplev=[10.,50.,70.,100.,125.,150.,175.,200.,225.,250.,275.,300.,325.,350.,$
  375.,400.,425.,450.,475.,500.,525.,550.,575.,600.,$
  625.,650.,675.,700.,725.,750.,775.,800.,825.,850,$
  875.,900.,925.,950.,975.,1000.,1025.,1050.,1075.,1100.]

; these are the levels output to netcdf file for spatial gridding
  subplev=[10., 50., 70., 100.,175.,200.,225.,300.,500.,700.,850.,975.]

;  pidx=intarr(n_elements(subplev))
;
; for p=0,n_elements(subplev)-1 do begin
;      diff = stdplev-subplev(p)
;      idx = where(abs(diff) eq min(abs(diff)))
;      pidx(p) = idx
;  endfor

; ----------------------------------------
; Read NUCAPS netcdf file
; ----------------------------------------

; this function reads the thinned NUCAPS file 
; that OSPO sends over SBN/NOAAPORT and returns 
; the variables as a nucaps structure
; As of Aug 2018, the field names relevant here are:
; - Temperature [K]
; - Pressure [hPa]
; - H2O  [molec/cm2]
; - O3 [molec/cm2]
; - CO [molec/cm2]

; extradir='nucaps/npp/'
  yy='2018'
  mm='03'
  dd='21'
  basedir='/iliad/proxy/nadias'
  ddir=basedir+'/'+capstype+'/'+instr+'/'+yy+'/'+mm+'/'+dd+'/netcdf'

; ----------------------------------------
; Define output filename
; ----------------------------------------
; this routine outputs a single file that combines all the retrievals
; for a given day and orbit, e.g., NUCAPS_SNPP_20180515_am.nc

  outfn=ddir+'/'+strupcase(capstype)+'_'+yy+mm+dd+'_'+orbit+'.nc'
  filespec=ddir+'/NUCAPS-sciEDR_'+orbit+'_'+instr+'*'+yy+mm+dd+'*STC_fsr.nc'
; find all the files in this directory
  filelist=findfile(filespec)
  nfiles=n_elements(filelist)
  print,'number of files ',nfiles
; loop over retrieval files
  keepcnt=0

  for i=0,nfiles-1 do begin
	fn=filelist(i)

	print,i,fn

; find the corresponding AK file
;        pos=strpos(fn,'_s20')
;        substr=strmid(fn,pos+2,14)
;	akfilespec=ddir+'/'+capstype+'_'+instr+'_'+orbit+'_*'+'s'+substr+'*AK.nc'
;        aklist=findfile(akfilespec)
;	akfn=aklist(0)
;	print,akfn
; Read NUCAPS
	read_nucaps,fn,caps
; Read NUCAPS AK file
;	read_nucaps_ak,akfn,capsak

	qc=caps.quality_flag
	if ( qflag eq 0 ) then idx=where(qc eq 0)
	if ( qflag eq 1 ) then idx=where(qc ge 0)
	Tair = caps.temperature
	plat=caps.latitude
	plon=caps.longitude
  	plev=caps.pressure(*,1)
	psurf=caps.surface_pressure
	nlev=n_elements(plev)
;
  p100idx = fltarr(n_elements(subplev))
  for p=0,n_elements(subplev)-1 do begin
      diff = plev-subplev(p)
      idx = where(abs(diff) eq min(abs(diff)))
      p100idx(p) = idx
  endfor

; define output arrays once you know the size of the granules and how many there are
	if i eq 0 then begin
		nprof = n_elements(plat)
   		nsamp = nfiles * nprof
		nsublev = n_elements(subplev)
		tair_out = fltarr(nsublev,nsamp)+fillval
		q_out = fltarr(nsublev,nsamp)+fillval
		o3_out = fltarr(nsublev,nsamp)+fillval
		co_out = fltarr(nsublev,nsamp)+fillval
		lat_out = fltarr(nsamp)+fillval
		lon_out = fltarr(nsamp)+fillval
		ctp = fltarr(nsamp)+fillval
		cfrac= fltarr(nsamp)+fillval
		tropT= fltarr(nsamp)+fillval
		tropP= fltarr(nsamp)+fillval
		tdof= fltarr(nsamp)+fillval
		o3dof= fltarr(nsamp)+fillval
		codof= fltarr(nsamp)+fillval
		qdof= fltarr(nsamp)+fillval
		eta = fltarr(nsamp)+fillval
		ampl = fltarr(nsamp)+fillval
		o3doftrop = fltarr(nsamp)+fillval
		o3dofstrat = fltarr(nsamp)+fillval
		h2odofbnd = fltarr(nsamp)+fillval
		h2odofmid = fltarr(nsamp)+fillval
		h2odoftop = fltarr(nsamp)+fillval
	endif

	; ----------------------------------------
	; 1. Get boundary layer array index, botlev
	; ---------------------------------------
	get_BL_params,plev,psurf,nprof,blmult,botlev
; apply surface correction
	for j=0,nprof-1 do begin
                sfc=botlev(j)
		q=caps.h2o(*,j)
		q(sfc)=q(sfc)*blmult(j)
		q(sfc+1:nlev-1)=!Values.F_NAN
		caps.h2o(*,j)=q

		q=caps.co(*,j)
                q(sfc)=q(sfc)*blmult(j)
                q(sfc+1:nlev-1)=!Values.F_NAN
		caps.co(*,j)=q

		q=caps.o3(*,j)
                q(sfc)=q(sfc)*blmult(j)
                q(sfc+1:nlev-1)=!Values.F_NAN
                caps.o3(*,j)=q
	end

	; ----------------------------------------
	; 2. Interpolate profile LEVELS
	; ----------------------------------------
  	interpolate_temperature,caps,stdplev,botlev,stdT; nlev x iobs
  	interpolate_gases,caps,stdplev,botlev,stdQ,stdCO,stdO3; nlev x iobs
        ; ----------------------------------------
	; 3. Unit conversions
        ; ----------------------------------------
	get_BL_params,stdplev,psurf,nprof,blmult,botlev
	convert_cd2mr,stdQ,stdCO,stdO3,stdplev,psurf,botlev,stdQmr,stdO3mr,stdCOmr
	; ----------------------------------------
	; 4. subset pressure levels and assign output arrays
	; ----------------------------------------
	; apply qc
	fill_val=!Values.F_NAN
	stdT(*,idx)=fill_val;!Values.F_NAN
;	stdQmr(*,idx)=fill_val;!Values.F_NAN
;	stdO3mr(*,idx)=fill_val;!Values.F_NAN
;	stdCOmr(*,idx)=fill_val;!Values.F_NAN
	caps.o3_mr(*,idx)=fill_val
	caps.co_mr(*,idx)=fill_val
	caps.h2o_mr(*,idx)=fill_val
	caps.cloud_top_pressure(*,idx)=fill_val;!Values.F_NAN
	caps.cloud_top_fraction(*,idx)=fill_val;!Values.F_NAN
	caps.rspare_field(*,idx)=fill_val;!Values.F_NAN
	caps.Trop_T(idx)=fill_val;!Values.F_NAN;
	caps.Trop_P(idx)=fill_val;!Values.F_NAN;
;	capsak.dofo3trop(idx)=fill_val
;	capsak.dofo3strat(idx)=fill_val
;	capsak.dofh2obnd(idx)=fill_val
;	capsak.dofh2omid(idx)=fill_val
;	capsak.dofh2otop(idx)=fill_val
	tair_out(*,keepcnt:keepcnt+nprof-1) = stdT(p100idx,*)
	 
	o3_out(*,keepcnt:keepcnt+nprof-1) = caps.o3_mr(p100idx,*)
	co_out(*,keepcnt:keepcnt+nprof-1) = caps.co_mr(p100idx,*)
	q_out(*,keepcnt:keepcnt+nprof-1) = caps.h2o_mr(p100idx,*)
	lat_out(keepcnt:keepcnt+nprof-1) = plat
	lon_out(keepcnt:keepcnt+nprof-1) = plon
	ctp(keepcnt:keepcnt+nprof-1)=caps.cloud_top_pressure(0,*); cloud top pressure
	cfrac(keepcnt:keepcnt+nprof-1)=caps.cloud_top_fraction(0,*); cloud top fraction
	eta(keepcnt:keepcnt+nprof-1)=caps.rspare_field(28,*); cloud clearing residual
	tdof(keepcnt:keepcnt+nprof-1)=caps.rspare_field(68,*); degrees of freedom
	qdof(keepcnt:keepcnt+nprof-1)=caps.rspare_field(69,*); degrees of freedom
	o3dof(keepcnt:keepcnt+nprof-1)=caps.rspare_field(70,*); degrees of freedom
	codof(keepcnt:keepcnt+nprof-1)=caps.rspare_field(73,*); degrees of freedom
	ampl(keepcnt:keepcnt+nprof-1)=caps.rspare_field(5,*); cloud clearing noise amplification factor
	tropT(keepcnt:keepcnt+nprof-1)=caps.Trop_T
	tropP(keepcnt:keepcnt+nprof-1)=caps.Trop_P
; Degrees of freedom
;	o3doftrop(keepcnt:keepcnt+nprof-1)=capsak.dofo3trop
;	o3dofstrat(keepcnt:keepcnt+nprof-1)=capsak.dofo3strat
;	h2odofbnd(keepcnt:keepcnt+nprof-1)=capsak.dofh2obnd
;	h2odofmid(keepcnt:keepcnt+nprof-1)=capsak.dofh2omid
;	h2odoftop(keepcnt:keepcnt+nprof-1)=capsak.dofh2otop

	; update counter
	keepcnt = keepcnt + nprof
endfor
; 
 idx=where(q_out lt -100)
 q_out(*,idx)=!Values.F_NAN
 idx=where(o3_out lt -100)
 o3_out(*,idx)=!Values.F_NAN
 idx=where(co_out lt -100)
 co_out(*,idx)=!Values.F_NAN
; ----------------------------------------
; Write output file
; ----------------------------------------
  write_ncdf,outfn,subplev,lat_out,lon_out,tair_out,ctp,$
       cfrac,tropT,tropP,eta,ampl,tdof, $
       q_out,co_out,o3_out,qdof,codof,o3dof,o3doftrop,o3dofstrat,$
	h2odofbnd,h2odofmid,h2odoftop
; now run space_gridding on outfn
end
