pro get_BL_params,pres,psurf,nobs,blmult,botlev

; --------------------------------
; This procedure calculates the boundary layer (BL) temperature
; and assigns it to the 10m temperature variable used in AWIPS
;
; This value is identical to the Surface_Temperature value in the NUCAPS netcdf file
;
; input = nucaps structure
; output = temp2m
; --------------------------------

; ********** notes on BL issue *********
;         find the bottom level of the atmosphere.  This ensures
;         that the bottom layer is not less that 5 mb
;         BLMULT will be <= 1.0 if this is the case
;          ------------- Pobs(numlev-1)
;                        ... this region must be >= 5 mbar
;          - - - - - - - Psurf
;          ------------- Pobs(numlev)
;
;         will add up to a 5 mb layer to the previous layer
;         if Psurf is close to the bottom level
;          ------------- Pobs(numlev-1)
;
;          ------------- Pobs(numlev)
;          - - - - - - - Psurf
;          BLMULT will be >= 1.0 and <= 1.25 if this is the case
;
;         0.20 < BLMULT < 1.2  (approximately 5/25 to 30/25 mb )
; ********* end notes on BL issue *********

  fillval = !Values.F_NAN

; determine size of NUCAPS arrays, i.e., number of retrievals

; define array that indicates the bottom level of profiles
  botlev = fltarr(nobs)
  blmult = fltarr(nobs)

; Loop over nobs and do interpolation one by one
  for iobs = 0, nobs - 1 do begin

    find_surface,pres,psurf(iobs),surflev,iobs

; calculate the boundary layer multiplier (BLMULT)
    num = psurf(iobs)-pres(surflev-1)
    denom = pres(surflev)-pres(surflev-1)
    blmult(iobs) = num/denom

    botlev(iobs) = surflev

  endfor
end
