pro interpolate_temperature,nucaps,stdplev,botlevel,stdT
; ---------------------------------
; procedure to interpolate a nucaps temperature profile from 
; 100 levels to the standard NWP levels
; 
; NOTE: I do not apply the BLMULT here because 
; 
; input: 
;   nucaps.temperature
;   nucaps.pressure
;   stdplev – NWP pressure levels
;   botlevel – array index at which nucaps.pressure <= surface_pressure
; output: 
;   stdT – nucaps temperature interpolated to NWP pressure levels
; ----------------------------------

  fillval = !Values.F_NAN

; extract NUCAPS vertical pressure grid to local variable
  pres = nucaps.pressure(*,0)
  nlev = n_elements(pres)

; calculate number of NWP pressure levels
  nlev_std = n_elements(stdplev)

; determine size of NUCAPS arrays, i.e., number of retrievals
  nobs = n_elements(nucaps.latitude)

; define output array
  stdT = fltarr(nlev_std,nobs)

; loop over each retrieval and interpolate profile by profile
  for iobs=0, nobs-1 do begin

   sfc = botlevel(iobs)
; set temperature values below surface pressure to FILL_VAL
   if sfc+1 eq nlev-1 then  nucaps.temperature(sfc+1,iobs) = fillval
   if sfc+1 lt nlev-1 then  nucaps.temperature(sfc+1:nlev-1,iobs) = fillval


; Temperature profile interpolation to standard pressure levels
    stdT(*,iobs) = INTERPOL(nucaps.temperature(*,iobs),pres,stdplev)

  endfor

    print,'Temperature interpolation done'
end

