pro make_ak_array,indir,xtype,sattype,param,orbit,akarr
; what you want to do here is read all the AK files in a directory
; extract the diagonal vector for each FOR
; assemble an array of all the AK-diag [nlev x nFOR*nscan]
; pass this on to space-gridding
; 
; ddir='/basis/something/YYYY/MM/DD/'
; xtype='clim' or 'nu'
; sattype='n20','snpp','aqua'
; param='air_temp','h2o_vap','o3','co'
; akarr.ak [nlev x nfor*nscan]
; akarr.lat [nfor*nscan]
; akarr.lon [nfor*nscan]
; akarr.plev [nlev]
;
; Nadia Smith
; 2 Sep 2019
;
; ===================================
; Read all the files in indir
; These files were created by callmerge.pro, calc_xcaps_ak.pro

; check if ddir needs a forward-slash
n=strlen(indir)
if strcmp(strmid(indir,n-1,1),'/') eq 0 then indir=indir+'/'
 
fillval=-999.
nan=!Values.F_NAN

; Get list of all the files in indir
filespec=indir+xtype+'caps_'+orbit+'_'+sattype+'*.nc'
filelist=findfile(filespec)
nfiles=n_elements(filelist)
print,strtrim(nfiles,1)+' files to process'

; extract date from files
fn=filelist(0)
pos=strpos(fn,sattype+'_s')
len=strlen(sattype+'_s')
datestr=strmid(fn,pos+len,8); YYYYMMDD

; Loop over files
for nf=0,nfiles-1 do begin
	fn=filelist(nf)
	out=read_ncdf(fn,dat)
; read values
	str='peff=dat.'+param+'_func_pres'
	dum=execute(str)
	qc=dat.qcmask; process only good AKs
	str='akmat=dat.'+param+'_ave_kern'
	dum=execute(str)
	str='botlev=dat.'+param+'_func_last_indx'
	dum=execute(str)
	s=size(akmat)
	nlev=ulong(s(3))
	nfor=ulong(s(1))
	dof=fltarr(nfor)
	if nf eq 0 then begin
		nobs=ulong(nfiles)*ulong(nfor)
		print,nobs
		akarr=create_struct('ak',fltarr(nlev,nobs))
		akarr=create_struct('lat',fltarr(nobs),akarr)
		akarr=create_struct('lon',fltarr(nobs),akarr)
		akarr=create_struct('dof',fltarr(nobs),akarr)
		akarr=create_struct('peff',fltarr(nlev),akarr)
		akarr.peff=peff
	endif
; extract AK diagonal
	ak=fltarr(nlev,nfor)-999.9
	for i=0,nfor-1 do begin
		blev=botlev(i)
		;if qc(i) eq 1 then ak(*,i)=diag_matrix(reform(akmat(i,*,*)))
		ak(*,i)=diag_matrix(reform(akmat(i,*,*)))
		dof(i)=total(ak(0:blev-1,i))
	endfor
; populate arrays
	sidx=ulong(nfor)*ulong(nf); start index
	eidx=ulong(nfor)*ulong(nf)+ulong(nfor)-1; end index
	print,'total obs',nobs,', file',nf,', start index',sidx,', end index',eidx
	akarr.ak(*,sidx:eidx)=ak
	akarr.lat(sidx:eidx)=dat.latitude
	akarr.lon(sidx:eidx)=dat.longitude
	akarr.dof(sidx:eidx)=dof
endfor; end loop over files

idx=where(akarr.ak le fillval)
akarr.ak(idx)=nan
idx=where(akarr.dof le fillval)
akarr.dof(idx)=nan
end
