pro make_ret_array,datestr,xtype,sattype,param,orbit,retarr
; what you want to do here is read all the AK files in a directory
; extract the diagonal vector for each FOR
; assemble an array of all the AK-diag [start:iend)nlev x nFOR*nscan]
; pass this on to space-gridding
; 
; Nadia Smith
; 2 Sep 2019
;
; ===================================
; Read all the files in indir
yy=strmid(datestr,0,4)
mm=strmid(datestr,4,2)
dd=strmid(datestr,6,2)

basedir='/ships19/aqda/nadias'

; derived values
if (strcmp(sattype,'n20')) then ddir=basedir+'/'+yy+'/'+mm+'/'+dd+'/retfiles/'

indir=ddir
fillval=-999.
nan=!Values.F_NAN

; Get list of all the files in indir
; These are still in binary format
filespec=indir+'*sciEDR*'+orbit+'*.nc'
print,filespec
print,indir
filelist=findfile(filespec)
nfiles=n_elements(filelist)
print,strtrim(nfiles,1)+' files to process'

; --- Load standard retrival pressure levels (pobs)
get_p100, pstd, pobs,peff=stdpeff

nlev=100L
retnlev=3; [300,500,800]
i3=where(abs(pobs-300) eq min(abs(pobs-300)))
i5=where(abs(pobs-500) eq min(abs(pobs-500)))
i7=where(abs(pobs-700) eq min(abs(pobs-700)))
pidx=[i3,i5,i7]
cnt=0L
; Loop over files
; irun=25 or 35 or 40 or 45
irun=40
for nf=0,nfiles-1 do begin
	fn=filelist(nf)
	print,fn
	if irun eq 40 and strlen(fn) gt 74 then begin
; open the retrieval file
        close, 4
	 out=read_ncdf(fn,ret)
        catch, error_status
        if error_status ne 0 then continue
	nfor=n_elements(ret.latitude)
	if nf eq 0 then begin
		nobs=ulong(nfiles)*ulong(nfor)
		print,'total number of retrievals ',nobs
		print,'total number of files ',nfiles
		print,'total number of FORs ',nfor
		retarr=create_struct('obs',fltarr(retnlev,nobs)*nan)
		retarr=create_struct('lat',fltarr(nobs),retarr)
		retarr=create_struct('lon',fltarr(nobs),retarr)
		retarr=create_struct('peff',fltarr(retnlev),retarr)
		retarr=create_struct('pobs',fltarr(retnlev),retarr)
		retarr.peff=ret.effective_pressure(pidx,0)
		retarr.pobs=ret.pressure(pidx,0)
	endif
		
	qc=0
	if qc eq 0 then begin
		istart=ulong(nf)*ulong(nfor)
		iend=ulong(istart+nfor-1)
	print,'processing file# ',nf,' records ',istart,':',iend
		if strcmp(param,'t') then retarr.obs(*,istart:iend)=ret.temperature(pidx,*)
		if strcmp(param,'q') then retarr.obs(*,istart:iend)=ret.h2o_mr(pidx,*)
		if strcmp(param,'co') then retarr.obs(*,istart:iend)=ret.co_mr(pidx,*)
		if strcmp(param,'ctp') then retarr.obs(*,istart:iend)=ret.cloud_top_pressure(0,*)
		if strcmp(param,'cfrac') then retarr.obs(*,istart:iend)=ret.cloud_top_fraction(0,*)
		if strcmp(param,'ccamp') then retarr.obs(*,istart:iend)=ret.rspare_field(5,*); cc amplification factor
		if strcmp(param,'cceta') then retarr.obs(*,istart:iend)=ret.rspare_field(28,*); cc residual
	endif
	retarr.lat(istart:iend)=ret.latitude
	retarr.lon(istart:iend)=ret.longitude

; populate arrays
	sidx=ulong(nfor)*ulong(nf); start index
	eidx=ulong(nfor)*ulong(nf)+ulong(nfor)-1; end index
	print,'total obs',nobs,', file',nf,', start index',sidx,', end index',eidx
	endif
endfor; end loop over files
retarr.obs(where(retarr.obs lt 0))=nan
end
