pro space_gridding_fg,ngrid,xtype,pval
; /iliad/proxy/nadias/nucaps/fg180321zone9.nc
; /iliad/proxy/nadias/climcaps/fg180321zone9.nc


ddir='/iliad/proxy/nadias/'+xtype+'caps/'
fnstr='fg180321.nc'
fn=ddir+fnstr

totobs=162000
lat_daily=fltarr(totobs)
lon_daily=fltarr(totobs)
capsqc=intarr(totobs)
capstemp=fltarr(totobs)

out=read_ncdf(fn,caps)
print,'reading file',fn
nobs=n_elements(caps.latitude)
	
lat_daily=caps.latitude
lon_daily=caps.longitude
pressure=caps.pressure 
capsqc=caps.qc
capstemp=reform(caps.temperature(pval,*)) 

idx=where(capstemp gt 0)
lat_daily=lat_daily(idx)
lon_daily=lon_daily(idx)
capsqc=capsqc(idx)
capstemp=capstemp(idx)


; Now that you have all the parameters together, you can make a global grid
FILL_VAL=-9999.
; Combine files together in one large array

; This routine sets all these variables according the the value of "ngrid"
call_res, ngrid, start_lat, end_lat, start_lon, end_lon, lat_inc, lon_inc, grid_res, nlatbins, nlonbins, minsample

; read input file
nlev=n_elements(pressure(pval))
; define grid arrays
; grid_res=nlat*nlon
T_mu = fltarr(grid_res)+FILL_VAL; 
T_median = fltarr(grid_res)+FILL_VAL; 
T_sigma = fltarr(grid_res)+FILL_VAL

        ;Q_mu = fltarr(nlev,grid_res)+FILL_VAL; 
        ;Q_sigma = fltarr(nlev,grid_res)+FILL_VAL; 
	;Qdof_mu = fltarr(grid_res)+FILL_VAL; 
	;Qdof_sigma = fltarr(grid_res)+FILL_VAL; 

sample_size = fltarr(grid_res)+FILL_VAL
glob_lat = fltarr(grid_res)
glob_lon = fltarr(grid_res)
anm = 0.0
; --------------
; Latitudinal histogram on Level 2 netcdf file
; --------------
hist_lat = histogram(lat_daily,min=start_lat,max=end_lat+lat_inc,binsize=lat_inc,reverse_indices=ri_lat)
for ii = 0,nlatbins-1 do begin; nlatbin comes from call_res.pro
; This condition happens when the histogram bins are empty; i.e., when the histogram range (min/max) is larger than the data range.
; You only need one of the sets of lat/longs to define the global lat/lon grids 

                  if(ri_lat[ii+1]-1 le ri_lat[ii]) then begin
; If there are empty bins, then fill the global lat/lon arrays with valid data and EXIT THE LOOP 
                             for jj = 0, nlonbins-1  do begin
                                     glob_lat[anm] = start_lat+(lat_inc/2.0)+ii*lat_inc
                                     glob_lon[anm] = start_lon+(lon_inc/2.0)+jj*lon_inc
                                     anm = anm + 1.0
                             endfor
                             goto, crap
                   endif
; Now you need to calculate the statistics for the gridded subsets of data as defined by the histogram bins
; According to http://www.faculty.virginia.edu/rwoclass/astr511/IDLresources/histogram_tutorial-JDSmith.html
; ri[ri[i]:ri[i]-1] will give you the range of indices for each subset. 

; The logic followed here is that you first do the latitude histogram and subsequent subset selection, 
;    then you do the longitude histogram on the latitudinal subset. 

; ---------------
; Create Latitudinal Subsets
; --------------
		lat_bin_index = ri_lat[ri_lat[ii]:ri_lat[ii+1]-1]
		lat_subset = lat_daily(lat_bin_index)
		lon_subset = lon_daily(lat_bin_index)
		tair = capstemp(lat_bin_index)
		hist_lon = histogram(lon_subset,min=start_lon,max=end_lon+lon_inc,binsize=lon_inc,reverse_indices=ri_lon)
; The first nlonbins-1 of the ri_lon array references the [nlonbins:anum_nfovs] of ri_lon
; You, therefore, do not need to loop through the entire ri_lon array
                for jj = 0, nlonbins-1  do begin
; test if lon-bins are empty
                       if(ri_lon[jj] ne ri_lon[jj+1]) then begin  
	                     	lon_bin_index = ri_lon[ri_lon[jj]:ri_lon[jj+1]-1]
; ------------Data Filtering Step------------
; NUCAPS QC=0 means "Best" IR/MW retrieval
; viewangle < scanlimit filters retrievals based on the scan angle. 
; Sanlimit=[0.-5.] keeps only nadir retrievals, scanlimit=32. keeps near-nadir retrievals and scanlimit=60. keeps all retrievals
; -------------------------------------------	
;				idxgood=where(capsqc(lon_bin_index) eq 0)
; Do statistics on minimum sample, which is calculated as 30% of the total FOR per grid cell (see call_res.pro below for details). 
; minsample varies per grid resolution. This keeps geostatistics consistent across scales.                                                      
minsample=1
				sample_size(anm)=n_elements(lon_bin_index)
					
; temperature profile
				result=Moment(tair(lon_bin_index))
				T_mu(anm)=result[0]; average
;				T_median(ilev,anm)=median(tair(ilev,lon_bin_index(idxgood))); 
				T_sigma(anm)=result[1]^0.5; standard deviation is sqrt of variance
			endif
			glob_lat[anm] = start_lat+(lat_inc/2.0)+ii*lat_inc
			glob_lon[anm] = start_lon+(lon_inc/2.0)+jj*lon_inc
			anm = anm + 1.0
		endfor
		crap:
		; do nothing
	endfor

	outfn=ddir+'fg180321_spacegrid_'+strtrim(round(pressure(pval)),1)+'hPa.nc'
	gres=fix(grid_res)
	cdfid=ncdf_create(outfn,/clobber)
	latlonid=ncdf_dimdef(cdfid,'LatxLon',gres)
	levid=ncdf_dimdef(cdfid,'pressure',nlev)
; lat/lon
	varid=ncdf_vardef(cdfid,'Latitude',[latlonid],/float)
        ncdf_control, cdfid, /endef
        ncdf_varput, cdfid, varid, glob_lat
        ncdf_control, cdfid, /redef
        varid=ncdf_vardef(cdfid,'Longitude',[latlonid],/float)
        ncdf_control, cdfid, /endef
        ncdf_varput, cdfid, varid, glob_lon
        ncdf_control, cdfid, /redef
; Temperature mean
	varid=ncdf_vardef(cdfid,'T_mu',[latlonid],/float)
	ncdf_control, cdfid, /endef
        ncdf_varput, cdfid, varid, T_mu
        ncdf_control, cdfid, /redef
; Temperature standard deviation
        varid=ncdf_vardef(cdfid,'T_sigma',[latlonid],/float)
        ncdf_control, cdfid, /endef
        ncdf_varput, cdfid, varid, T_sigma
        ncdf_control, cdfid, /redef
	
print,'values written to ',outfn
end


; =======================================================
; *******************************************************
; =======================================================

PRO  call_res, ngrid, start_lat, end_lat, start_lon, end_lon, lat_inc, lon_inc, grid_res, nlatbins, nlonbins,minsample
; The argument for the minsample definition is as follows:
;   1.5deg = ~150km = 3 x 50km along one axis and 3 x 3 = 9 FOVs per grid cell
;   2deg = ~200km = 4 x 50km...16 FOVs
;   3deg = ~300km = 6 x 50km...36 FOVs
;   4deg = ~400km = 8 x 50km...64 FOVs
;   6deg = ~600km = 12 x 50km...144 FOVs
;   12deg = ~1200km = 24 x 50km...576 FOVs
;   minsample is 30% of total. This is high given that I concluded that the minimum
; sample size should be ... what did I say in that paper? 

  if(ngrid eq 1) then begin  ; 1.5x1.5 deg res
       start_lat = -90.0
       end_lat = 88.5
       start_lon = -180.0
       end_lon = 178.5
       lat_inc = 1.5
       lon_inc = 1.5
       nlatbins = 120
       nlonbins = 240
       grid_res = 120.0*240.0
       minsample = 3
  endif

  if(ngrid eq 2) then begin  ; 2x2 deg res
       start_lat = -90.0
       end_lat = 88.0
       start_lon = -180.0
       end_lon = 178.0
       lat_inc = 2.0
       lon_inc = 2.0
       nlatbins = 90
       nlonbins = 180
       grid_res = 90.0*180.0
       minsample = 5
  endif
  if(ngrid eq 3) then begin  ; 3x3 deg res
       start_lat = -90.0
       end_lat = 87.0
       start_lon = -180.0
       end_lon = 177.0
       lat_inc = 3.0
       lon_inc = 3.0
       nlatbins = 60
       nlonbins = 120
       grid_res = 60.0*120.0
       minsample = 11
  endif

  if(ngrid eq 4) then begin  ; 4x4 deg res
       start_lat = -90.0
       end_lat = 86.0
       start_lon = -180.0
       end_lon = 176.0
       lat_inc = 4.0
       lon_inc = 4.0
       nlatbins = 45
       nlonbins = 90
       grid_res = 45.0*90.0
       minsample = 24
  endif

  if(ngrid eq 5) then begin  ; 6x6 deg res
       start_lat = -90.0
       end_lat = 84.0
       start_lon = -180.0
       end_lon = 174.0
       lat_inc = 6.0
       lon_inc = 6.0
       nlatbins = 30
       nlonbins = 60
       grid_res = 30.0*60.0
       minsample = 43
  endif

  if(ngrid eq 6) then begin  ; 12x12 deg res
       start_lat = -90.0
       end_lat = 78.0
       start_lon = -180.0
       end_lon = 168.0
       lat_inc = 12.0
       lon_inc = 12.0
       nlatbins = 15
       nlonbins = 30
       grid_res = 15.0*30.0
       minsample = 176
  endif

end
