pro space_gridding_ret,ngrid,datestr,param,orbit,sattype,xtype

; input variables
;	xtype='clim'
;	sattype='n20'
;	param='o3'; 'air_temp','h2o_vap','co'
;	orbit='am'
yy=strmid(datestr,0,4)
mm=strmid(datestr,4,2)
dd=strmid(datestr,6,2)

ngrid=uint(ngrid)

; Data directory
indir='/ships19/aqda/nadias/'+yy+'/'+mm+'/'+dd+'/retfiles/'

        FILL_VAL=-999.9
        nan=!Values.F_NAN	
; define outfile name
	outfn=indir+xtype+'caps_'+datestr+'_'+orbit+'_'+sattype+'_gridded_'+param+'_ret_'+strtrim(ngrid,1)+'deg.nc'
; This routine sets all these variables according the the value of "ngrid"
        call_res, ngrid, start_lat, end_lat, start_lon, end_lon, lat_inc, lon_inc, grid_res, nlatbins, nlonbins, minsample

; Combine files together in one large array
; Call make_ak_array to assembel AK-diag from files in indir into a single array
	make_ret_array,datestr,xtype,sattype,param,orbit,retarr
        lat_daily=retarr.lat; [nobs]
	lon_daily=retarr.lon; [nobs]
	plev=retarr.pobs; [nlev x nobs]
	obs=retarr.obs; [nlev]
	nlev=n_elements(plev)
; Define grid arrays
; Grid_res=nlat*nlon
	obs_mu = fltarr(nlev,grid_res)*nan; 
	obs_sigma = fltarr(nlev,grid_res)*nan
	sample_size = fltarr(grid_res)*nan
	glob_lat = fltarr(grid_res)
	glob_lon = fltarr(grid_res)
	
	anm = 0.0

; --------------
; Latitudinal histogram on Level 2 netcdf file
; --------------
	hist_lat = histogram(lat_daily,min=start_lat,max=end_lat+lat_inc,binsize=lat_inc,reverse_indices=ri_lat)
	for ii = 0,nlatbins-1 do begin; nlatbin comes from call_res.pro
; This condition happens when the histogram bins are empty; i.e., when the histogram range (min/max) is larger than the data range.
; You only need one of the sets of lat/longs to define the global lat/lon grids 
                   if(ri_lat[ii+1]-1 le ri_lat[ii]) then begin
; If there are empty bins, then fill the global lat/lon arrays with valid data and EXIT THE LOOP 
                             for jj = 0, nlonbins-1  do begin
                                     glob_lat[anm] = start_lat+(lat_inc/2.0)+ii*lat_inc
                                     glob_lon[anm] = start_lon+(lon_inc/2.0)+jj*lon_inc
                                     anm = anm + 1.0
                             endfor
                             goto, crap
                   endif
; Now you need to calculate the statistics for the gridded subsets of data as defined by the histogram bins
; According to http://www.faculty.virginia.edu/rwoclass/astr511/IDLresources/histogram_tutorial-JDSmith.html
; ri[ri[i]:ri[i]-1] will give you the range of indices for each subset. 

; The logic followed here is that you first do the latitude histogram and subsequent subset selection, 
;    then you do the longitude histogram on the latitudinal subset. 

; ---------------
; Create Latitudinal Subsets
; --------------

		lat_bin_index = ri_lat[ri_lat[ii]:ri_lat[ii+1]-1]
		lat_subset = lat_daily(lat_bin_index)
		lon_subset = lon_daily(lat_bin_index)
		obs_subset = obs(*,lat_bin_index)
help,obs_subset
print,max(obs_subset,/nan),':',min(obs_subset,/nan)
		hist_lon = histogram(lon_subset,min=start_lon,max=end_lon+lon_inc,binsize=lon_inc,reverse_indices=ri_lon)
; The first nlonbins-1 of the ri_lon array references the [nlonbins:anum_nfovs] of ri_lon
; You, therefore, do not need to loop through the entire ri_lon array
                for jj = 0, nlonbins-1  do begin
; test if lon-bins are empty
                       if(ri_lon[jj] ne ri_lon[jj+1]) then begin  
	                     	lon_bin_index = ri_lon[ri_lon[jj]:ri_lon[jj+1]-1]
; ------------Data Filtering Step------------
; NUCAPS QC=0 means "Best" IR/MW retrieval
; viewangle < scanlimit filters retrievals based on the scan angle. 
; Sanlimit=[0.-5.] keeps only nadir retrievals, scanlimit=32. keeps near-nadir retrievals and scanlimit=60. keeps all retrievals
; -------------------------------------------	
				idxgood=where(obs_subset(0,lon_bin_index) gt 0)
; Do statistics on minimum sample, which is calculated as 30% of the total FOR per grid cell (see call_res.pro below for details). 
; minsample varies per grid resolution. This keeps geostatistics consistent across scales.                                                      
minsample=1
				if(n_elements(idxgood) ge minsample) then begin

					sample_size(anm)=n_elements(idxgood)

					for ilev=0,nlev-1 do begin
						result=Moment(obs_subset(ilev,lon_bin_index(idxgood)),/nan)
						obs_mu(ilev,anm)=mean(obs_subset(ilev,lon_bin_index(idxgood)),/nan);result[0]; average
						obs_sigma(ilev,anm)=result[1]^0.5; standard deviation is sqrt of variance
					endfor
				endif
			endif
			glob_lat[anm] = start_lat+(lat_inc/2.0)+ii*lat_inc
			glob_lon[anm] = start_lon+(lon_inc/2.0)+jj*lon_inc
			anm = anm + 1.0
			;print,anm,glob_lat[anm-1.0],glob_lon[anm-1.0],start_lat,lat_inc,start_lon,lon_inc,ii,jj
		endfor
		crap:
		; do nothing
	endfor
	gres=fix(grid_res)
	cdfid=ncdf_create(outfn,/clobber)
	latlonid=ncdf_dimdef(cdfid,'LatxLon',gres)
	levid=ncdf_dimdef(cdfid,'plev',nlev)
; pressure
	varid=ncdf_vardef(cdfid,'Effective_Pressure',[levid],/float)
	ncdf_control,cdfid,/endef
	ncdf_varput,cdfid,varid,plev
	ncdf_control,cdfid,/redef
; lat/lon
	varid=ncdf_vardef(cdfid,'Latitude',[latlonid],/float)
        ncdf_control, cdfid, /endef
        ncdf_varput, cdfid, varid, glob_lat
        ncdf_control, cdfid, /redef
        varid=ncdf_vardef(cdfid,'Longitude',[latlonid],/float)
        ncdf_control, cdfid, /endef
        ncdf_varput, cdfid, varid, glob_lon
        ncdf_control, cdfid, /redef
        
; Averaging Kernel mean
	varid=ncdf_vardef(cdfid,'obs_mu',[levid,latlonid],/float)
	ncdf_control, cdfid, /endef
        ncdf_varput, cdfid, varid, obs_mu
        ncdf_control, cdfid, /redef
; Averaging Kernel standard deviation
        varid=ncdf_vardef(cdfid,'obs_sigma',[levid,latlonid],/float)
        ncdf_control, cdfid, /endef
        ncdf_varput, cdfid, varid, obs_sigma
        ncdf_control, cdfid, /redef
; close the file
        ncdf_close,cdfid
	print,'output saved to ',outfn
end


; =======================================================
; *******************************************************
; =======================================================

PRO  call_res, ngrid, start_lat, end_lat, start_lon, end_lon, lat_inc, lon_inc, grid_res, nlatbins, nlonbins,minsample
; The argument for the minsample definition is as follows:
;   1.5deg = ~150km = 3 x 50km along one axis and 3 x 3 = 9 FOVs per grid cell
;   2deg = ~200km = 4 x 50km...16 FOVs
;   3deg = ~300km = 6 x 50km...36 FOVs
;   4deg = ~400km = 8 x 50km...64 FOVs
;   6deg = ~600km = 12 x 50km...144 FOVs
;   12deg = ~1200km = 24 x 50km...576 FOVs
;   minsample is 30% of total. This is high given that I concluded that the minimum
; sample size should be ... what did I say in that paper? 

  if(ngrid eq 1) then begin  ; 1.5x1.5 deg res
       start_lat = -90.
       end_lat = 90.0
       start_lon = -180.0
       end_lon = 178.5
       lat_inc = 1.5
       lon_inc = 1.5
       nlatbins = 120
       nlonbins = 240
       grid_res = 120.0*240.0
       minsample = 3
  endif

  if(ngrid eq 2) then begin  ; 2x2 deg res
       start_lat = -90.0
       end_lat = 88.0
       start_lon = -180.0
       end_lon = 178.0
       lat_inc = 2.0
       lon_inc = 2.0
       nlatbins = 90
       nlonbins = 180
       grid_res = 90.0*180.0
       minsample = 5
  endif
  if(ngrid eq 3) then begin  ; 3x3 deg res
       start_lat = -90.0
       end_lat = 87.0
       start_lon = -180.0
       end_lon = 177.0
       lat_inc = 3.0
       lon_inc = 3.0
       nlatbins = 60
       nlonbins = 120
       grid_res = 60.0*120.0
       minsample = 11
  endif

  if(ngrid eq 4) then begin  ; 4x4 deg res
       start_lat = -90.0
       end_lat = 86.0
       start_lon = -180.0
       end_lon = 176.0
       lat_inc = 4.0
       lon_inc = 4.0
       nlatbins = 45
       nlonbins = 90
       grid_res = 45.0*90.0
       minsample = 24
  endif

  if(ngrid eq 5) then begin  ; 6x6 deg res
       start_lat = -90.0
       end_lat = 84.0
       start_lon = -180.0
       end_lon = 174.0
       lat_inc = 6.0
       lon_inc = 6.0
       nlatbins = 30
       nlonbins = 60
       grid_res = 30.0*60.0
       minsample = 43
  endif

  if(ngrid eq 6) then begin  ; 12x12 deg res
       start_lat = -90.0
       end_lat = 78.0
       start_lon = -180.0
       end_lon = 168.0
       lat_inc = 12.0
       lon_inc = 12.0
       nlatbins = 15
       nlonbins = 30
       grid_res = 15.0*30.0
       minsample = 176
  endif

end
