pro nsplot_stgrid_global_AK,xtype,iparam,orbit,sattype,datestr
; param='air_temp','h2o_vap','o3'
jname='test.jpg'
!except=0

paramlist=['air_temp','h2o_vap','o3','co','ch4','co2','hno3']
xnamelist=['T','H!I2!NO','O!I3!N','CO','CH!I4!N','CO!I2!N','HNO!I3!N']
param=paramlist(iparam)
xtit=xnamelist(iparam)

gidx=1
if gidx eq 1 then gridarr=[1.5,240,120];[gsize,nlon, nlat] 1.5deg
if gidx eq 2 then gridarr=[2,180,90]; 2deg
if gidx eq 3 then gridarr=[3,120,60]; 3deg
if gidx eq 4 then gridarr=[4,90,45]; 4deg
if gidx eq 5 then gridarr=[6,60,30]; 6deg

gridstr=strtrim(gidx,1)+'deg'

yy=strmid(datestr,0,4)
mm=strmid(datestr,4,2)
dd=strmid(datestr,6,2)

ddir='/peate_sci/nadias/ak/'+yy+'/'+mm+'/'+dd+'/'

filespec=ddir+xtype+'caps_'+datestr+'*'+orbit+'*'+sattype+'*'+param+'_ave_kern_'+gridstr+'.nc'
print,filespec
infn=findfile(filespec)
print,infn

figtit=datestr+' '+orbit+' '+strupcase(xtype)+'CAPS '+strupcase(sattype)+' '+xtit

out=read_ncdf(infn,dat)
;   EFFECTIVE_PRESSURE FLOAT     Array[9]
;   LATITUDE        FLOAT     Array[1800]
;   LONGITUDE       FLOAT     Array[1800]
;   DOF_MU          FLOAT     Array[1800]
;   DOF_SIGMA       FLOAT     Array[1800]
;   AK_MU           FLOAT     Array[9, 1800]
;   AK_SIGMA        FLOAT     Array[9, 1800]
plev=dat.effective_pressure
plat=dat.latitude
plon=dat.longitude
mdof=dat.dof_mu; mean DOF
sdof=dat.dof_sigma; standard deviation DOF
mak=dat.ak_mu; mean Averaging Kernel
sak=dat.ak_sigma; standard deviaiton Averaging Kernel

nlev=n_elements(plev)
ngrid=n_elements(nlon)
nlon=gridarr(1)
nlat=gridarr(2)

;plat=reform(plat,nlon,nlat)
;plon=reform(plon,nlon,nlat)
;mdof=reform(mdof,nlon,nlat)
;sdof=reform(sdof,nlon,nlat)
;mak=reform(mak,nlev,nlon,nlat)
;sak=reform(sak,nlev,nlon,nlat)

;******* Make Figures *********


;====================
; Degrees of freedom
;====================
; Mean
xmax=max(mdof)
xmin=min(mdof)
loadct,10
m = map('Miller',$
 dimensions=[1200, 1000], $
 /nodata,$
 buffer=1,limit=[-90,-180,90,180], $
 margin=[0.1,0.05,0.1,0.05],$
 title=figtit,font_size=22,color='gray')
 mygrid = m.mapgrid
 mygrid.linestyle='dotted'
 mygrid.font_size=14
 mygrid.grid_longitude=40
 mygrid.grid_latitude=20
 mygrid.label_position=-0.05
 mygrid.font_style=1
 mygrid.box_axes=1
 mygrid.box_thick=1

	;rgb=colortable([[1,231,247],[48,158,232],[0,50,188],$
	;[131,113,202],[255,54,54],[218,143,93],[236,246,103]],ncolors=256)

        rgb=colortable(['lavender','sandy brown','royal blue','aqua'],ncolors=256)

myimage=image(mdof,plon,plat,/buffer,/current,overplot=m,$
        grid_units='degrees',$
        rgb_table=rgb,$
        max_value=xmax,min_value=xmin)

cb=colorbar(rgb_table=rgb,textpos=0, taper=1, $
        border=1, orientation=0, range=[xmin,xmax], $
        font_size=18,title=xtit+' Degrees of Freedom for Signal',position=[0.2,0.12,0.8,0.14] )

	jname=xtype+'caps_'+sattype+'_'+orbit+'_'+datestr+'_'+param+'_DOF.jpg'
	m.save, jname, resolution=120
	print,'figure saved as '+jname

; StDev

;====================
; Averaging Kernels
;====================
; Loop over pressure layers and plot AKs at each layer
; MEAN Ave Kernel
istype=strcmp(xtype,'clim')
case 1 of
	strcmp(param,'air_temp') and (istype eq 1): psubset=[9,10,13,16,18,23]; 70,96,195,306,399,694
	strcmp(param,'air_temp') and (istype eq 0): psubset=[9,11,13,15,17,19]; 63,110,185,306,459,628
	strcmp(param,'h2o_vap') and (istype eq 1): psubset=[4,7,9,11,14,16]; 195,306,399,506,694,827
	strcmp(param,'h2o_vap') and (istype eq 0): psubset=[2,3,5,7,9]; 217,293,374,565,777
	strcmp(param,'co')      : psubset=[2,3,4,5,6,7]
	strcmp(param,'o3')      : psubset=[2,3,4,5,6,7]
	else	  : psubset=[0:nlev-1]
endcase

foreach ilev,psubset do begin
	ak=reform(mak(ilev,*,*))
	xmax=max(ak)
	xmin=min(ak)
	loadct,10
	m = map('Miller',$
	 dimensions=[1200, 1000], $
	 /nodata,$
	 buffer=1,limit=[-90,-180,90,180], $
	 margin=[0.1,0.05,0.1,0.05],$
	 title=figtit,font_size=22,color='gray')

	 mygrid = m.mapgrid
	 mygrid.linestyle='dotted'
	 mygrid.font_size=14
	 mygrid.grid_longitude=40
	 mygrid.grid_latitude=20
	 mygrid.label_position=-0.05
	 mygrid.font_style=1
	 mygrid.box_axes=1
	 mygrid.box_thick=1

	myimage=image(ak,plon,plat,/buffer,/current,overplot=m,$
        grid_units='degrees',$
        rgb_table=rgb,$
        max_value=xmax,min_value=xmin)
;	m2=mapcontinents()
	coltit=xtit+' Ave Kernel Diag at '+strtrim(uint(plev(ilev)),1)+'hPa'
	cb=colorbar(rgb_table=rgb,textpos=0, taper=1, $
        border=1, orientation=0, range=[xmin,xmax], $
        font_size=18,title=coltit,position=[0.2,0.12,0.8,0.14] )

; save figure
	jname=xtype+'caps_'+sattype+'_'+orbit+'_'+datestr+'_'+param+'_AK_'+strtrim(uint(plev(ilev)),1)+'hPa.jpg'
	m.save, jname, resolution=120
	print,'figure saved as '+jname
endforeach; loop over pressure layers

; STDEV Ave Kernel
;
end
